package com.huiju.estateagents.center.taUser.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.taUser.entity.TaUser;
import com.huiju.estateagents.center.taUser.service.ITaUserService;
import com.huiju.estateagents.common.CommConstant;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
    * 用户表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-11
 */
@RestController
@RequestMapping("/api")
public class TaUserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaUserController.class);

    @Autowired
    public ITaUserService iTaUserService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/center/taUser",method= RequestMethod.GET)
    public ResponseBean taUserList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage pg = new Page<>(pageNum, pageSize);
            IPage<Map<String,Object>> result = iTaUserService.getPageList(pg);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taUser 实体对象
     * @return
     */
    @RequestMapping(value="/center/taUser",method= RequestMethod.POST)
    public ResponseBean taUserAdd(@RequestBody TaUser taUser){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaUserService.save(taUser)){
                responseBean.addSuccess(taUser);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taUser/{id}", method= RequestMethod.DELETE)
    public ResponseBean taUserDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaUserService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taUser 实体对象
     * @return
     */
    @RequestMapping(value="/taUser/{id}",method= RequestMethod.PUT)
    public ResponseBean taUserUpdate(@PathVariable Integer id,
                                        @RequestBody TaUser taUser){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaUserService.updateById(taUser)){
                responseBean.addSuccess(taUser);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taUser/{id}",method= RequestMethod.GET)
    public ResponseBean taUserGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaUserService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taUserDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
