package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.ExtendContent;
import com.huiju.estateagents.entity.TaBuildingDynamic;
import com.huiju.estateagents.service.IExtendContentService;
import com.huiju.estateagents.service.ITaBuildingDynamicService;
import com.huiju.estateagents.service.ITaBuildingService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;

/**
 * <p>
    * 辅助内容表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class ExtendContentController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(ExtendContentController.class);

    @Autowired
    public IExtendContentService iExtendContentService;

    @Autowired
    private ITaBuildingDynamicService iTaBuildingDynamicService;

    @Autowired
    private ITaBuildingService iTaBuildingService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/extendContent",method= RequestMethod.GET)
    public ResponseBean extendContentList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                          @RequestParam(value = "buildingId", required = false) String buildingId,
                                          @RequestParam(value = "contentType", required = false) String contentType,
                                          @RequestParam(value = "showPosition", required = false) String showPosition,
                                          @RequestParam(value = "status", required = false) Integer status,
                                          @RequestParam(value = "showType", required = false) String showType){
        ResponseBean responseBean = new ResponseBean();
            IPage<ExtendContent> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<ExtendContent> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq(StringUtils.isNotBlank(buildingId), "building_id", buildingId);
            queryWrapper.eq(StringUtils.isNotBlank(showType), "show_type", showType);
            queryWrapper.eq(StringUtils.isNotBlank(contentType), "content_type", contentType);
            queryWrapper.eq(StringUtils.isNotBlank(showPosition), "show_position", showPosition);
            queryWrapper.eq(null!=status, "status", status);
            queryWrapper.orderByDesc("create_date");
            IPage<ExtendContent> result = iExtendContentService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
            return responseBean;
    }

    /**
     * 微信 开屏 / 轮播图
     */
    @RequestMapping(value="/wx/extendContent/{showType}",method= RequestMethod.GET)
    public ResponseBean extendContentListShowType(@PathVariable(value = "showType") String showType,
                                                  @RequestParam(value = "showPosition", required = false) String showPosition,
                                                  @RequestParam(value = "targetId", required = false) String targetId,
                                                  @RequestParam(value = "contentType", required = false) String contentType,
                                                  @RequestParam(value = "buildingId", required = false) String buildingId,
                                                  @RequestParam(value = "contentId", required = false) String contentId,
                                                  @RequestParam(value = "cityId", required = false) Integer cityId){
        ResponseBean responseBean= iExtendContentService.selectExtendContentListShowType(showType, showPosition, targetId,contentType, buildingId, contentId, cityId);
        return responseBean;
    }


    /**
     * 保存对象
     * @param extendContent 实体对象
     * @return
     */
    @RequestMapping(value="/admin/extendContent",method= RequestMethod.POST)
    public ResponseBean extendContentAdd(@RequestBody ExtendContent extendContent){
        Integer cityId = iTaBuildingService.getCityById(extendContent.getBuildingId());
        extendContent.setCityId(cityId);
        extendContent.setCreateDate(LocalDateTime.now());
        ResponseBean  responseBean= iExtendContentService.extendContentAdd(extendContent);
          responseBean.addSuccess(extendContent);
          return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/extendContent/{id}", method= RequestMethod.DELETE)
    public ResponseBean extendContentDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iExtendContentService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param extendContent 实体对象
     * @return
     */
    @RequestMapping(value="/admin/extendContent/{id}",method= RequestMethod.PUT)
    public ResponseBean extendContentUpdate(@PathVariable Integer id,
                                        @RequestBody ExtendContent extendContent){
        ResponseBean responseBean = new ResponseBean();
        extendContent.setContentId(id);
        try {
            Integer cityId = iTaBuildingService.getCityById(extendContent.getBuildingId());
            extendContent.setCityId(cityId);
            if (iExtendContentService.updateById(extendContent)){
                responseBean.addSuccess(extendContent);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/extendContent/{id}",method= RequestMethod.GET)
    public ResponseBean extendContentGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            ExtendContent extendContent = iExtendContentService.getById(id);
            TaBuildingDynamic taBuildingDynamic = iTaBuildingDynamicService.getById(extendContent.getTargetId());
            if (null != taBuildingDynamic) {
                extendContent.setTargetName(taBuildingDynamic.getTitle());
            }

            responseBean.addSuccess(extendContent);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("extendContentDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
