package com.huiju.estateagents.controller;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.bean.WxMaJscode2SessionResult;
import cn.binarywang.wx.miniapp.bean.WxMaPhoneNumberInfo;
import cn.binarywang.wx.miniapp.bean.WxMaUserInfo;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.WxUtils;
import com.huiju.estateagents.entity.*;
import com.huiju.estateagents.event.EventBus;
import com.huiju.estateagents.mapper.TaShareMapper;
import com.huiju.estateagents.service.IMiniAppService;
import com.huiju.estateagents.service.ITaCustomerPersonService;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.service.ITaRecommendCustomerService;
import me.chanjar.weixin.common.error.WxErrorException;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/api/wx")
public class MiniAppController {
    @Autowired
    private ITaPersonService taPersonService;

    final WxMaService wxService = WxUtils.getMiniApp();

    @Autowired
    private IMiniAppService miniAppService;

    @Autowired
    private ITaRecommendCustomerService taRecommendCustomerService;

    @Autowired
    private ITaCustomerPersonService taCustomerPersonService;

    @Resource
    private ApplicationContext applicationContext;

    @Autowired
    private TaShareMapper taShareMapper;



    /**
     * 验证接入
     */
    @GetMapping(value = "/", produces = "text/plain;charset=utf-8")
    public String access(@RequestParam(name = "signature", required = false) String signature,
                          @RequestParam(name = "timestamp", required = false) String timestamp,
                          @RequestParam(name = "nonce", required = false) String nonce,
                          @RequestParam(name = "echostr", required = false) String echostr) {
        return echostr;
    }

    /**
     * 登陆接口
     */
    @PostMapping("/login")
    public ResponseBean login(String code,@RequestParam(required = false) String from,@RequestParam(required = false)String recommender) {
        if (StringUtils.isBlank(code)) {
            return ResponseBean.error("参数 code 不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        try {
            WxMaJscode2SessionResult session = miniAppService.getSessionInfo(code);

            Map<String, String> miniResp = new HashMap<>();
            miniResp.put("openid", session.getOpenid());
            miniResp.put("sessionKey", session.getSessionKey());
            miniResp.put("unionid", session.getUnionid());
            miniResp.put("token", JWTUtils.newToken(session.getOpenid()));
            //如果是分享进来且没有进入过小程序，给分享人发放积分
            QueryWrapper<TaPerson> personQueryWrapper = new QueryWrapper<>();
            personQueryWrapper.eq("mini_openid",session.getOpenid());
            int count = taPersonService.count(personQueryWrapper);

            if(from.contains("share") && StringUtils.isNotBlank(recommender) && count>0){
                // 添加积分
                 applicationContext.publishEvent(new EventBus(recommender, EventBus.EventType.SharePosterAll));
            }
            TaPerson taPerson = taPersonService.newPersonByOpenid(session.getOpenid());
            if (null == taPerson) {
                return ResponseBean.error("发生未知错误", ResponseBean.ERROR_UNAVAILABLE);
            }
            if(StringUtils.isEmpty(taPerson.getFromCode())){
                taPerson.setFromCode(from);
            }
            if(StringUtils.isEmpty(taPerson.getRecommendPerson())){
                taPerson.setRecommendPerson(recommender);
                TaPerson type = taPersonService.getById(recommender);
                if(null != type){
                    if(!StringUtils.isEmpty(type.getPersonType())){
                        taPerson.setRecommendPersonType(type.getPersonType());
                    }
                }
            }
            taPersonService.updateById(taPerson);

            taPerson.setPassword(null);

            // 获取其余信息
            Map<String, Object> extraInfo = taPersonService.getExtraInfo(taPerson.getPersonId());

            Map<String, Object> result = new HashMap<>();
            result.put("miniApp", miniResp);
            result.put("person", taPerson);
            result.put("extraInfo", extraInfo);
            result.put("miniAuthorized", null != taPerson.getAvatarurl() && taPerson.getAvatarurl().indexOf("wx.qlogo.cn") > 0);


            return ResponseBean.success(result);
        } catch (WxErrorException e) {
            System.err.println(e.getError());
            return ResponseBean.error("解析小程序 code 失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 登陆接口
     */
    @PostMapping("/logout")
    public ResponseBean logout(HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> persons = taPersonService.getPersonsByOpenId(openid);
        if (null == persons || persons.size() == 0) {
            return ResponseBean.success("");
        }

        return ResponseBean.success("");
    }


    /**
     * 获取用户信息, 并写入内部人员表
     */
    @PostMapping("/signup")
    public ResponseBean info(@RequestBody String paramStr, HttpServletRequest request) {
        TaPerson person = null;

        if (null == paramStr || "".equals(paramStr.trim()) || "{}".equals(paramStr.trim())) {
            String openid = JWTUtils.getSubject(request);
            List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
            if (null == taPersons || taPersons.size() != 1) {
                return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
            }
            person = taPersons.get(0);
        } else {

            JSONObject params = JSONObject.parseObject(paramStr);
            if (null == params) {
                return ResponseBean.error("校验参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }

            String sessionKey = params.getString("sessionKey");
            String signature = params.getString("signature");
            String rawData = params.getString("rawData");
            String encryptedData = params.getString("encryptedData");
            String iv = params.getString("iv");

            // 用户信息校验
            if (!miniAppService.checkUserInfo(sessionKey, rawData, signature)) {
                return ResponseBean.error("校验参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }

            // 解密用户信息
            WxMaUserInfo userInfo = miniAppService.getUserInfo(sessionKey, encryptedData, iv);

            // 更新或保存用户信息
            person = taPersonService.mergePersonWxInfo(userInfo);
            if (null == person) {
                return ResponseBean.error("发生未知错误", ResponseBean.ERROR_UNAVAILABLE);
            }
        }

        // 获取其余信息
        Map<String, Object> extraInfo = taPersonService.getExtraInfo(person.getPersonId());
        person.setPassword(null);

        Map<String, Object> result = new HashMap<>();
        result.put("person", person);
        result.put("extraInfo", extraInfo);

        return ResponseBean.success(result);
    }

    /**
     * 获取用户绑定手机号信息
     */
    @PostMapping("/userPhone")
    public ResponseBean phone(@RequestBody String paramStr, HttpServletRequest request) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("校验参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String sessionKey = params.getString("sessionKey");
        String encryptedData = params.getString("encryptedData");
        String iv = params.getString("iv");

        // 解密
        WxMaPhoneNumberInfo phoneNoInfo = miniAppService.getPhoneNoInfo(sessionKey, encryptedData, iv);

        // 更新用户绑定手机
        String openid = JWTUtils.getSubject(request);
        taPersonService.updatePersonPhone(openid, phoneNoInfo.getPhoneNumber());
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        person.setPersonType(CommConstant.PERSON_ESTATE_AGENT);
        taPersonService.updateById(person);
        QueryWrapper<TaRecommendCustomer> cus= new QueryWrapper<>();
        cus.eq("phone",phoneNoInfo.getPhoneNumber());
        cus.orderByDesc("create_date");
        List<TaRecommendCustomer> customer = taRecommendCustomerService.list(cus);
        if (customer.size()>0){
            for(int i =0;i<customer.size();i++){
                customer.get(i).setPersonId(person.getPersonId());
                customer.get(i).setPicture(person.getAvatarurl());
                customer.get(i).setCountry(person.getCountry());
                customer.get(i).setCity(person.getCity());
                customer.get(i).setProvince(person.getProvince());
            }
//            TaRecommendCustomer customers = customer.get(0);

            if(!taRecommendCustomerService.updateBatchById(customer)){
                return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
            }
//            if(null != customers.getRecommendPerson()&&!StringUtils.isEmpty(customers.getRecommendPerson())&& StringUtils.isEmpty(person.getRecommendPerson())){
//                person.setRecommendPerson(customers.getRecommendPerson());
//                person.setRecommendPerson(customers.getRecommendPerson());
//                TaPerson recommender = taPersonService.getById(customers.getRecommendPerson());
//                if(null != recommender.getPersonType()&&!StringUtils.isEmpty(recommender.getPersonType())){
//                    person.setRecommendPersonType(recommender.getPersonType());
//                }
//            }

//            QueryWrapper<TaCustomerPerson> customerPersonQueryWrapper = new QueryWrapper<>();
//            customerPersonQueryWrapper.eq("person_id",person.getPersonId());
//            customerPersonQueryWrapper.eq("customer_id",customers.getCustomerId());
//            List<TaCustomerPerson> list = taCustomerPersonService.list(customerPersonQueryWrapper);
//            if(list.size()<=0){
//                taCustomerPersonService.insertBean(person.getPersonId(),customers.getCustomerId());
//            }
        } else{
            TaRecommendCustomer reCustomer = new TaRecommendCustomer();
            reCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
            reCustomer.setName(person.getNickname());
            reCustomer.setPhone(phoneNoInfo.getPhoneNumber());
            reCustomer.setSex(Integer.valueOf(person.getGender()));
            reCustomer.setPersonId(person.getPersonId());
            reCustomer.setPicture(person.getAvatarurl());
            reCustomer.setCountry(person.getCountry());
            reCustomer.setCity(person.getCity());
            reCustomer.setProvince(person.getProvince());
            reCustomer.setEntryType(CommConstant.ENTRY_VOLUNTEER);
            reCustomer.setCreateDate(LocalDateTime.now());
            reCustomer.setReportRecommendStatus(CommConstant.READY);
            if(!taRecommendCustomerService.save(reCustomer)){
                return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
            }
        }
        return ResponseBean.success(phoneNoInfo);
    }

    /**
     * 生成二维码
     * @return
     */
    @PostMapping("/qrcode")
    public ResponseBean qrcode(@RequestBody String paramsStr) {
        return miniAppService.getQrCode(paramsStr);
    }

    /**
     * 获取二维码参数
     * @param serialNo
     * @return
     */
    @GetMapping("/qrcode/scene/{serialNo}")
    public ResponseBean getScene(@PathVariable String serialNo) {
        try {
            Integer id = Integer.valueOf(serialNo);
            TaMiniappQrcode qrcode = miniAppService.getQrCodeBySerialNo(id);
            if (null == qrcode) {
                return ResponseBean.error("不存在的二维码参数", HttpStatus.SC_BAD_REQUEST);
            }

            return ResponseBean.success(qrcode.getQrParams());
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseBean.error("获取二维码参数失败: " + e.getMessage(), HttpStatus.SC_INTERNAL_SERVER_ERROR);
        }
    }
}
