package com.huiju.estateagents.controller;

import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.service.IStatisticalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDate;
import java.util.Date;

/**
 * 数据统计
 */
@RestController
@RequestMapping("/api")
public class StatisticalController {

    @Autowired
    private IStatisticalService iStatisticalService;

    /**
     * 首页统计
     * @return
     */
    @GetMapping(value = "/admin/indexStatistical")
    public ResponseBean indexStatistical() {
        return iStatisticalService.indexStatistical();
    }

    /**
     * 活跃用户数
     * @return
     */
    @GetMapping(value = "/admin/selectActiveUserCount")
    public ResponseBean selectActiveUserCount(@RequestParam String dateType,
                                              @RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                              @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate) {
        return iStatisticalService.selectActiveUserCount(dateType, startDate,endDate);
    }

    /**
     * 新增用户数
     * @return
     */
    @GetMapping(value = "/admin/selectNewsUserCount")
    public ResponseBean selectNewsUserCount(@RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                            @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate) {
        return iStatisticalService.selectNewsUserCount(startDate, endDate);
    }

    /**
     * 转化率 统计
     * @return
     */
    @GetMapping(value = "/admin/selectConversion")
    public ResponseBean selectConversion(@RequestParam("conversion") String conversion) {
        return iStatisticalService.selectConversion(conversion);
    }

    /**
     * 用户行为
     * @return
     */
    @GetMapping(value = "/admin/selectUserBehavior")
    public ResponseBean selectUserBehavior(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                           @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                           @RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                           @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate,
                                           @RequestParam(value = "buildingId", required = false) String buildingId,
                                           @RequestParam(value = "eventType", required = false) String eventType,
                                           @RequestParam(value = "event", required = false) String event,
                                           @RequestParam(value = "activity", required = false) String activity) {
        return iStatisticalService.selectUserBehavior(pageNum, pageSize, startDate, endDate, buildingId, eventType, event, activity);
    }

    /**
     * 行为分析的 具体事件数据列表
     * @return
     */
    @GetMapping(value = "/admin/selectEventAll")
    public ResponseBean selectEventAll(@RequestParam(required = false) String event,
                                              @RequestParam(required = false) String personId) {
        return iStatisticalService.selectEventAll(event, personId);
    }


    /**
     * 用户来源
     * @return
     */
    @GetMapping(value = "/admin/selectUserResource")
    public ResponseBean selectUserResource(@RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                           @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)  LocalDate endDate) {
        return iStatisticalService.selectUserResource(startDate, endDate);
    }


    /**
     * 用户总数
     * @return
     */
    @GetMapping(value = "/admin/selectUserCount")
    public ResponseBean selectUserResource() {
        return iStatisticalService.selectUserCount();
    }

    /**
     * 用户注册数
     * @return
     */
    @GetMapping(value = "/admin/selectRegisteredCount")
    public ResponseBean selectRegisteredCount() {
        return iStatisticalService.selectRegisteredCount();
    }

    /**
     * 用户最近七天
     * @return
     */
    @GetMapping(value = "/admin/selectRecentlyCount")
    public ResponseBean selectRecentlyCount(@RequestParam(value = "startDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate startDate,
                                            @RequestParam(value = "endDate", required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDate endDate) {
        return iStatisticalService.selectRecentlyCount(startDate, endDate);
    }

    /**
     * 性别比例
     * @return
     */
    @GetMapping(value = "/admin/selectSexUser")
    public ResponseBean selectSexUser() {
        return iStatisticalService.selectSexUser();
    }

    /**
     * 城市比例
     * @return
     */
    @GetMapping(value = "/admin/selectCityUser")
    public ResponseBean selectCityUser() {
        return iStatisticalService.selectCityUser();
    }

    /**
     * 意向用户  首页
     * @return
     */
    @GetMapping(value = "/admin/selectIntentionUser")
    public ResponseBean selectIntentionUser(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                            @RequestParam(value = "pageSize", defaultValue = "2") Integer pageSize,
                                            @RequestParam(value = "buildingId", required = false) String buildingId) {
        return iStatisticalService.selectIntentionUser(pageNum, pageSize, buildingId);
    }

}
