package com.huiju.estateagents.controller;


import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaBuilding;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.service.ITaBuildingService;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.ITaSaveService;
import com.huiju.estateagents.service.ITdCityService;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.*;

import com.huiju.estateagents.base.BaseController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 项目表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@RestController
@RequestMapping("/api")
public class TaBuildingController extends BaseController {

    @Autowired
    ITaBuildingService taBuildingService;

    @Autowired
    ITaSaveService iTaSaveService;

    @Autowired
    ITaPersonService iTaPersonService;


    /**
     * 楼盘详情
     * @param id
     * @return
     */
    @GetMapping("/admin/buildingSelectId/{id}")
    public ResponseBean buildingSelectId(@PathVariable(value = "id") String id){
        return taBuildingService.buildingSelectId(id);
    }

    /**
     * 楼盘列表 查询所有有效的
     * @param pageNum
     * @param pageSize
     * @param name
     * @param code
     * @return
     */
    @GetMapping("/admin/buildinglist")
    public ResponseBean buildingList(@RequestParam(value = "pageNum", defaultValue = "1")Integer pageNum,
                                     @RequestParam(value = "pageSize", defaultValue = "10")Integer pageSize,
                                     @RequestParam(value = "name", required = false)String name,
                                     @RequestParam(value = "code", required = false)String code,
                                     @RequestParam(value = "startDate",required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)LocalDateTime startDate,
                                     @RequestParam(value = "buildingStatus",required = false)String buildingStatus,
                                     @RequestParam(value = "marketStatus",required = false)String marketStatus,
                                     @RequestParam(value = "cityId",required = false)Integer cityId,
                                     @RequestParam(value = "isMain",required = false)Integer isMain){
        return taBuildingService.buildingList(pageNum,pageSize,name,code,startDate,buildingStatus,marketStatus,cityId,isMain);
    }

    /**
     * 楼盘列表
     * @param pageNum
     * @param pageSize
     * @param name
     * @param code
     * @return
     */
    @GetMapping("/admin/buildinglist/select")
    public ResponseBean buildingListSelect(@RequestParam(value = "pageNum", defaultValue = "1")Integer pageNum,
                                     @RequestParam(value = "pageSize", defaultValue = "10")Integer pageSize,
                                     @RequestParam(value = "name", required = false)String name,
                                     @RequestParam(value = "code", required = false)String code,
                                     @RequestParam(value = "startDate",required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)LocalDateTime startDate,
                                     @RequestParam(value = "buildingStatus",required = false)String buildingStatus,
                                     @RequestParam(value = "marketStatus",required = false)String marketStatus,
                                     @RequestParam(value = "cityId",required = false)Integer cityId,
                                     @RequestParam(value = "isMain",required = false)Integer isMain){
        return taBuildingService.buildingListSelect(pageNum,pageSize,name,code,startDate,buildingStatus,marketStatus,cityId,isMain);
    }

    /**
     * 更新楼盘
     * @param parameter
     * @return
     */
    @PutMapping("/admin/building/update")
    public ResponseBean buildingUpdate(@RequestBody String parameter){
        return taBuildingService.buildingUpdate(parameter);
    }

    /**
     * 楼盘添加
     * @param parameter
     * @return
     */
    @RequestMapping(value = "/admin/building/add", method = RequestMethod.POST)
    public ResponseBean buildingAdd(@RequestBody String parameter){
        return taBuildingService.buildingAdd(parameter);
    }

    /**
     * 楼盘发布
     * @param parameter
     * @return
     */
    @RequestMapping(value = "/admin/building/update/status", method = RequestMethod.PUT)
    public ResponseBean buildingUpdateStatus(@RequestBody String parameter){
        return taBuildingService.buildingUpdateStatus(parameter);
    }

    /**
     * 楼盘删除
     * @param id
     * @param session
     * @return
     */
    @RequestMapping(value = "/admin/building/delete/{id}", method = RequestMethod.DELETE)
    public ResponseBean buildingdelete(@PathVariable("id") String id, HttpSession session){
        return taBuildingService.buildingdelete(id);
    }

    /**
     * 添加户型
     * @param parameter
     * @param session
     * @return
     */
    @RequestMapping(value = "/admin/buildingApartment/add", method = RequestMethod.POST)
    public ResponseBean buildingApartment(@RequestBody String parameter, HttpSession session){
        return taBuildingService.buildingApartmentAdd(parameter);
    }

    /**
     * 户型编辑
     * @param parameter
     * @return
     */
    @RequestMapping(value = "/admin/buildingApartment/update", method = RequestMethod.PUT)
    public ResponseBean buildingApartmentUpdate(@RequestBody String parameter){
        return taBuildingService.buildingApartmentUpdate(parameter);
    }

    /**
     * 楼盘详情
     * @param id
     * @return
     */
    @RequestMapping(value = "/admin/buildingApartment/{id}", method = RequestMethod.GET)
    public ResponseBean buildingApartmentSelectId(@PathVariable(value = "id") String id){
        return taBuildingService.buildingApartmentSelectId(id);
    }

    /**
     * 依据项目ID 查户型
     * @param id
     * @return
     */
    @RequestMapping(value = "/admin/buildingApartment/buildingId/{id}", method = RequestMethod.GET)
    public ResponseBean buildingApartmentBuildingId(@PathVariable(value = "id") String id){
        return taBuildingService.buildingApartmentBuildingId(id);
    }

    /**
     * 微信楼盘列表
     * @return
     */
    @RequestMapping(value = "/wx/building/list", method = RequestMethod.GET)
    public ResponseBean getWxBuildingList(
            @RequestParam(defaultValue = "1") Integer pageNum,
            @RequestParam(defaultValue = "10")Integer pageSize,
            @RequestParam(defaultValue = "false") Boolean mine,
            @RequestParam(required = false) Integer cityId,
            @RequestParam(required = false) String name,
            @RequestParam(required = false) String buildingType, // 项目类型Id
            @RequestParam(required = false) String houseType, // 户型
            @RequestParam(required = false) String price,   // 价格
            @RequestParam(required = false) String area,    // 面积
//            @RequestParam(required = false) Integer minPrice, // 最低价格
//            @RequestParam(required = false) Integer maxPrice, // 最高价格
//            @RequestParam(required = false) Double minBuildingArea, // 最小面积
//            @RequestParam(required = false) Double maxBuildingArea, // 最大面积
            HttpServletRequest request
    ){
        List<String> targets = null;
        if (null != mine && mine) {
            String openid = JWTUtils.getSubject(request);
            List<TaPerson> persons = iTaPersonService.getPersonsByOpenId(openid);
            if (null == persons || persons.size() == 0) {
                return ResponseBean.error("当前账户信息异常, 清除缓存重试", ResponseBean.ERROR_UNAVAILABLE);
            }

            targets = iTaSaveService.getTargesOfPerson(persons.get(0).getPersonId(), CommConstant.FAVOR_PROJECT);
        }

        String[] buildingTypeList = !StringUtils.isEmpty(buildingType) ? buildingType.split(",") : null;
        String[] houseTypeList = !StringUtils.isEmpty(houseType) ? houseType.split(",") : null;
        List<String[]> priceList = getParamListOf(price);
        List<String[]> areaList = getParamListOf(area);

        return taBuildingService.getWxBuildingList(pageNum, pageSize, name, targets, cityId,mine, houseTypeList, buildingTypeList, priceList, areaList);
    }


    /**
     * 先按照 逗号 拆分, 再按照 横线 拆分
     * @param params
     * @return
     */
    private List<String[]> getParamListOf(String params) {
        List<String[]> paramList = new ArrayList<>();

        if (null == params || "".equals(params.trim())) {
            return paramList;
        }

        String[] paramsArray = params.split(",");
        for(String param : paramsArray) {
            paramList.add(param.split("-"));
        }

        return paramList;
    }


    /**
     * 微信推荐楼盘列表
     * @return
     */
    @RequestMapping(value = "/wx/building/mian", method = RequestMethod.GET)
    public ResponseBean getWxMainBuildingList(){
        return taBuildingService.getWxMainBuildingList();
    }

    /**
     * 删除户型
     * @param id
     * @return
     */
    @RequestMapping(value = "/admin/apartment/deleted/{id}", method = RequestMethod.DELETE)
    public ResponseBean apartmentDeleted(@PathVariable(value = "id") String id){
        return taBuildingService.apartmentDel(id);
    }

    /**
     * 微信楼盘详情
     * @param id
     * @return
     */
    @RequestMapping(value = "/wx/buildingSelectId/{id}", method = RequestMethod.GET)
    public ResponseBean wxBuildingSelectId(@PathVariable(value = "id") String id,HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> persons = iTaPersonService.getPersonsByOpenId(openid);
        if (null == persons || persons.size() == 0) {
            return ResponseBean.error("当前账户信息异常, 清除缓存重试", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = persons.get(0);
        return taBuildingService.buildingAllSelectId(id,person.getPersonId());
    }
    /**
     * 查询当前所有项目
     */
    @RequestMapping(value = "/admin/buildingAll", method = RequestMethod.GET)
    public  ResponseBean buildingAll(){
        ResponseBean taBuilding= taBuildingService.buildingAll();
        return taBuilding;
    }
}

