package com.huiju.estateagents.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.*;
import com.huiju.estateagents.mapper.TaActivityDynamicEnlistMapper;
import com.huiju.estateagents.mapper.TaBuildingMapper;
import com.huiju.estateagents.service.ITaBuildingDynamicService;
import com.huiju.estateagents.service.ITaBuildingService;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.ITaSaveService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import javax.swing.*;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 * 项目动态表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@RestController
@RequestMapping("/api")
public class TaBuildingDynamicController extends BaseController {

    @Autowired
    private ITaBuildingDynamicService iBuildingDynamicService;

    @Autowired
    private TaBuildingMapper taBuildingMapper;

    @Autowired
    private ITaPersonService taPersonService;

    @Autowired
    private ITaSaveService taSaveService;

    @Autowired
    private ITaBuildingService iTaBuildingService;

    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @RequestMapping(value = "/admin/iBuildingDynamicList", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicList(@RequestParam("pageNum")Integer pageNum,
                                             @RequestParam("pageSize")Integer pageSize,
                                             @RequestParam(required = false)String name,
                                             @RequestParam(required = false)Integer cityId,
                                             @RequestParam(required = false)String buildingId,
                                             @RequestParam(required = false)String isEnlist,
                                             @RequestParam(required = false) @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME) LocalDateTime time){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicList(pageNum,pageSize,name,buildingId,cityId,isEnlist,time);
        return responseBean;
    }

    @RequestMapping(value = "/admin/iBuildingDynamicSelectId/{id}", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicSelectId(@PathVariable(value = "id") String id, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicSelectId(id);
        return responseBean;
    }

    /**
     * 活动列表
     * @param pageNum
     * @param pageSize
     * @param request
     * @return
     */
    @RequestMapping(value = "/wx/buildingDynamiceList", method = RequestMethod.GET)
    public ResponseBean wxBuildingDynamiceList(@RequestParam(value = "buildingId", required = false)String buildingId,
                                               @RequestParam(value = "pageNum",defaultValue = "1")Integer pageNum,
                                               @RequestParam(value = "pageSize",defaultValue = "10")Integer pageSize,
                                               @RequestParam(defaultValue = "false" )boolean mine,
                                               @RequestParam(value = "cityId", required = false)Integer cityId,
                                               HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        ResponseBean  responseBean = new ResponseBean();
        if(mine){
            List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
            if (null == taPersons || taPersons.size() != 1) {
                return responseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
            }
            TaPerson person = taPersons.get(0);
            responseBean.addSuccess(iBuildingDynamicService.getJoinedActivity(pageNum,pageSize,"",person));
        }else {
            responseBean = iBuildingDynamicService.getWxBuildingDynamiceList(pageNum,pageSize,buildingId,openid,cityId);
        }

        return responseBean;
    }

    /**
     * 活动列表
     * @param pageNum
     * @param pageSize
     * @param request
     * @return
     */
    @RequestMapping(value = "/wx/save/buildingDynamiceList", method = RequestMethod.GET)
    public ResponseBean wxSaveBuildingDynamiceList(@RequestParam(value = "buildingId", required = false)String buildingId,
                                               @RequestParam(value = "pageNum",defaultValue = "1")Integer pageNum,
                                               @RequestParam(value = "pageSize",defaultValue = "10")Integer pageSize,
                                               HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        ResponseBean  responseBean = new ResponseBean();
            List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
            if (null == taPersons || taPersons.size() != 1) {
                return responseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
            }
            TaPerson person = taPersons.get(0);
            QueryWrapper<TaSave> saveQueryWrapper = new QueryWrapper<>();
            saveQueryWrapper.eq("person_id",person.getPersonId());
            saveQueryWrapper.eq("tagert_type", CommConstant.FAVOR_ACTIVITY);
            List<TaSave> saveList = taSaveService.list(saveQueryWrapper);
            if(saveList.size()>0){
                List<String> ids = new ArrayList<>();
                for(int i = 0; i<saveList.size();i++){
                    ids.add(saveList.get(i).getSavedTarget());
                }
                IPage<TaBuildingDynamic> page = new Page<>(pageNum, pageSize);
                QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
                buildingDynamicQueryWrapper.in("dynamic_id",ids);
                IPage<TaBuildingDynamic> buildingDynamicIPage = iBuildingDynamicService.page(page,buildingDynamicQueryWrapper);
                for(int j=0;j<buildingDynamicIPage.getRecords().size();j++){
                    iBuildingDynamicService.setExtendInfo(buildingDynamicIPage.getRecords().get(j),person);
                }
                responseBean.addSuccess(buildingDynamicIPage);
            }else {
                responseBean.addSuccess("暂无收藏活动");
            }


        return responseBean;
    }

    /**
     * 活动详情
     * @param dynamicId
     * @return
     */
    @RequestMapping(value = "/wx/buildingDynamiceInfo/{dynamicId}", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicInfo(@PathVariable(value = "dynamicId") String dynamicId,
                                             HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        String buildingId = "";
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceInfo(dynamicId,buildingId,openid);
        return responseBean;
    }

    /**
     * 添加活动报名
     * @param taActivityDynamicEnlist
     * @param request
     * @return
     */
    @RequestMapping(value = "/wx/activityDynamicEnlistAdd", method = RequestMethod.POST)
    public ResponseBean taActivityDynamicEnlist(@RequestBody TaActivityDynamicEnlist taActivityDynamicEnlist,
                                                HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        taActivityDynamicEnlist.setPersonId(person.getPersonId());
        ResponseBean  responseBean = iBuildingDynamicService.taActivityDynamicEnlistAdd(taActivityDynamicEnlist);
        return responseBean;
    }


    @RequestMapping(value = "/admin/buildingDynamic/add" ,method =RequestMethod.POST)
    public  ResponseBean buildingDynamicAdd(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        TaBuildingDynamic dynamic = JSONObject.parseObject(parameter, TaBuildingDynamic.class);
        Integer cityId = iTaBuildingService.getCityById(dynamic.getBuildingId());
        dynamic.setCityId(cityId);
        dynamic.setStatus(1);
//        dynamic.setDynamicId(idGen.nextId()+"");
        dynamic.setPublishDate(LocalDateTime.now());
        dynamic.setCreateDate(LocalDateTime.now());
        iBuildingDynamicService.save(dynamic);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/update" ,method =RequestMethod.PUT)
    public  ResponseBean buildingDynamicUpdate(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        TaBuildingDynamic dynamic = JSONObject.parseObject(parameter, TaBuildingDynamic.class);
        QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        Integer cityId = iTaBuildingService.getCityById(dynamic.getBuildingId());
        dynamic.setCityId(cityId);
        buildingDynamicQueryWrapper.eq("dynamic_id", dynamic.getDynamicId());
        iBuildingDynamicService.update(dynamic, buildingDynamicQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/weight" ,method =RequestMethod.PUT)
    public  ResponseBean buildingDynamicWeight(@RequestParam String dynamicId,@RequestParam Integer weight){
        ResponseBean responseBean = new ResponseBean();
        TaBuildingDynamic dynamic = iBuildingDynamicService.getById(dynamicId);
        dynamic.setWeight(weight);
        QueryWrapper<TaBuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id",dynamic);
        if (iBuildingDynamicService.updateById(dynamic)){
            responseBean.addSuccess("成功");
        }else {
            responseBean.addError("失败");
        }
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/delete", method = RequestMethod.DELETE)
    public ResponseBean buildingDynamicdelect(@RequestParam(value = "id",required = false)String id) {
        ResponseBean responseBean = iBuildingDynamicService.buildingDynamicDelete(id);
        return responseBean;
    }


    @RequestMapping(value = "/admin/buildingDynamic/send/{dynamicId}", method = RequestMethod.PUT)
    public ResponseBean send(@PathVariable String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<TaBuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        TaBuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        dynamic.setStatus(1);
        dynamic.setPublishDate(LocalDateTime.now());
        iBuildingDynamicService.update(dynamic, dynamicQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/cancel/{dynamicId}", method = RequestMethod.PUT)
    public ResponseBean cancel(@PathVariable String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<TaBuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        TaBuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        dynamic.setStatus(0);
        iBuildingDynamicService.update(dynamic, dynamicQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/Details", method = RequestMethod.GET)
    public ResponseBean buildingDynamicDetails(@RequestParam("dynamicId")String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<TaBuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        TaBuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        TaBuilding building= taBuildingMapper.selectBuilding(dynamic.getBuildingId());

        if (null != building) {
            dynamic.setBuildingName(building.getBuildingName());
        }

        responseBean.addSuccess(dynamic);
        return responseBean;
    }

    @RequestMapping(value = "/admin/SignList", method = RequestMethod.GET)
    public ResponseBean getSignList(@RequestParam(value = "pageNum",defaultValue = "1")Integer pageNum,
                                    @RequestParam(value = "pageSize",defaultValue = "10")Integer pageSize,
                                    @RequestParam(value = "dynamicId",required = false)String dynamicId) {
        Page<TaActivityDynamicEnlist> page = new Page<>();
        page.setSize(pageSize);
        page.setCurrent(pageNum);
        ResponseBean signList = iBuildingDynamicService.signList(page,dynamicId);

        HashMap<String, Object> map = new HashMap<>();
        map.put("list", signList);
        map.put("total", page.getTotal());
        map.put("pageNum", page.getCurrent());
        map.put("pageSize", page.getSize());
        return ResponseBean.success(map);
    }

    @RequestMapping(value = "/admin/buildingDynamic/finish" ,method =RequestMethod.PUT)
    public  ResponseBean buildingDynamicFinish(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        JSONObject object = JSONObject.parseObject(parameter);
        String dynamicId = object.getString("dynamicId");
        String top = object.getString("top");
        QueryWrapper<TaBuildingDynamic> taBuildingDynamic = new QueryWrapper<>();
        taBuildingDynamic.eq("dynamic_id", dynamicId);
        TaBuildingDynamic dynamic = iBuildingDynamicService.getOne(taBuildingDynamic);
        if ("1".equals(top)) {
            dynamic.setCreateDate(LocalDateTime.now());
        } else {
            dynamic.setIsEnlist("2");
        }
        iBuildingDynamicService.update(dynamic, taBuildingDynamic);
        responseBean.addSuccess("成功");
        return responseBean;
    }



}

