package com.huiju.estateagents.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaChannel;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.TaChannelService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;


/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-17
 */
@RestController
@RequestMapping("/api")
public class TaChannelController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaChannelController.class);

    @Autowired
    public TaChannelService taChannelService;

    @Autowired
    public ITaPersonService taPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/channel",method= RequestMethod.GET)
    public ResponseBean channelList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaChannel> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaChannel> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaChannel> result = taChannelService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param channel 实体对象
     * @return
     */
    @RequestMapping(value="/channel",method= RequestMethod.POST)
    public ResponseBean channelAdd(@RequestBody TaChannel channel){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (taChannelService.save(channel)){
                responseBean.addSuccess(channel);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/channel/{id}", method= RequestMethod.DELETE)
    public ResponseBean channelDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(taChannelService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param channel 实体对象
     * @return
     */
    @RequestMapping(value="/channel/{id}",method= RequestMethod.PUT)
    public ResponseBean channelUpdate(@PathVariable Integer id,
                                        @RequestBody TaChannel channel){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (taChannelService.updateById(channel)){
                responseBean.addSuccess(channel);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/channel/{id}",method= RequestMethod.GET)
    public ResponseBean channelGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taChannelService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 渠道管理下的经纪人
     */
    @RequestMapping(value="/channel/broker",method= RequestMethod.GET)
    public  ResponseBean channelBrokerList(@RequestBody String  Param,
                                           @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        JSONObject jSONObject = JSONObject.parseObject(Param);
        String name = jSONObject.getString("name");
        String phone = jSONObject.getString("phone");
        ResponseBean taPerson =  taPersonService.channelBrokerList(name,phone,pageNum,pageSize);
        return taPerson;
    }
}
