package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaChannelPerson;
import com.huiju.estateagents.service.TaChannelPersonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-17
 */
@RestController
@RequestMapping("/api")
public class TaChannelPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaChannelPersonController.class);

    @Autowired
    public TaChannelPersonService iChannelPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/channelPerson",method= RequestMethod.GET)
    public ResponseBean channelPersonList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                          @RequestParam(value = "channelName",required = false)String channelName  ){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaChannelPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaChannelPerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("channel_name",channelName);
            queryWrapper.orderByDesc("create_date");

            IPage<TaChannelPerson> result = iChannelPersonService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelPersonList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param channelPerson 实体对象
     * @return
     */
    @RequestMapping(value="/channelPerson",method= RequestMethod.POST)
    public ResponseBean channelPersonAdd(@RequestBody TaChannelPerson channelPerson){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iChannelPersonService.save(channelPerson)){
                responseBean.addSuccess(channelPerson);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelPersonAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/channelPerson/{id}", method= RequestMethod.DELETE)
    public ResponseBean channelPersonDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iChannelPersonService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelPersonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param channelPerson 实体对象
     * @return
     */
    @RequestMapping(value="/channelPerson/{id}",method= RequestMethod.PUT)
    public ResponseBean channelPersonUpdate(@PathVariable Integer id,
                                        @RequestBody TaChannelPerson channelPerson){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iChannelPersonService.updateById(channelPerson)){
                responseBean.addSuccess(channelPerson);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelPersonUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/channelPerson/{id}",method= RequestMethod.GET)
    public ResponseBean channelPersonGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iChannelPersonService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelPersonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
