package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaGoods;
import com.huiju.estateagents.service.ITaBuildingService;
import com.huiju.estateagents.service.ITaGoodsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.lang.invoke.ConstantCallSite;

/**
 * <p>
    * 商品表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class TaGoodsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGoodsController.class);

    @Autowired
    public ITaGoodsService iTaGoodsService;

    @Autowired
    public ITaBuildingService iTaBuildingService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taGoods",method= RequestMethod.GET)
    public ResponseBean taGoodsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                    @RequestParam(value = "goodsName",required = false) String goodsName,
                                    @RequestParam(value = "buildingId",required = false) String buildingId,
                                    @RequestParam(value ="priceLesser",required = false) Integer priceLesser,
                                    @RequestParam(value ="priceGreater",required = false) Integer priceGreater,
                                    @RequestParam(value ="status",required = false) Integer status){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaGoods> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaGoods> queryWrapper = new QueryWrapper<>();
            queryWrapper.like(!StringUtils.isEmpty(goodsName),"goods_name",goodsName);
            queryWrapper.lt(null!=priceGreater,"point_price",priceGreater);
            queryWrapper.gt(null != priceLesser,"point_price",priceLesser);
            queryWrapper.eq(null != status,"status",status);
            queryWrapper.eq(!StringUtils.isEmpty(buildingId),"building_id",buildingId);
            queryWrapper.orderByDesc("create_date");

            IPage<TaGoods> result = iTaGoodsService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taGoods 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taGoods/add",method= RequestMethod.POST)
    public ResponseBean taGoodsAdd(@RequestBody TaGoods taGoods){
        ResponseBean responseBean = new ResponseBean();
        try {

            Integer cityId = iTaBuildingService.getCityById(taGoods.getBuildingId());
            taGoods.setCityId(cityId);

            if (iTaGoodsService.save(taGoods)){
                responseBean.addSuccess(taGoods);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taGoods/{id}", method= RequestMethod.DELETE)
    public ResponseBean taGoodsDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaGoodsService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taGoods 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taGoods",method= RequestMethod.PUT)
    public ResponseBean taGoodsUpdate(@RequestBody TaGoods taGoods){
        ResponseBean responseBean = new ResponseBean();
        try {

            Integer cityId = iTaBuildingService.getCityById(taGoods.getBuildingId());
            taGoods.setCityId(cityId);

            if (iTaGoodsService.updateById(taGoods)){
                responseBean.addSuccess(taGoods);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 修改对象
     * @param taGoods 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taGoods/change",method= RequestMethod.PUT)
    public ResponseBean taGoodsChange(@RequestBody TaGoods taGoods){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(null != taGoods.getStatus() && taGoods.getStatus().equals(CommConstant.STATUS_NORMAL)){
                taGoods.setStatus(CommConstant.STATUS_UNACCALIMED);
            }else {
                taGoods.setStatus(CommConstant.STATUS_NORMAL);
            }
            if (iTaGoodsService.updateById(taGoods)){
                responseBean.addSuccess(taGoods);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taGoods/{id}",method= RequestMethod.GET)
    public ResponseBean taGoodsGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaGoodsService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/goods",method= RequestMethod.GET)
    public ResponseBean wxGoodsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                    @RequestParam(value = "buildingId",required = false) String buildingId,
                                    @RequestParam(value = "orgId",required = false) Integer orgId){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaGoods> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaGoods> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("status", CommConstant.STATUS_NORMAL);
            if (!StringUtils.isEmpty(buildingId)){
                queryWrapper.eq("building_id", buildingId);
            }
            if (null != orgId){
                queryWrapper.eq("org_id", orgId);
            }
            queryWrapper.orderByDesc("order_no");
            queryWrapper.orderByDesc("create_date");
            
            IPage<TaGoods> result = iTaGoodsService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    
    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/goods/{id}",method= RequestMethod.GET)
    public ResponseBean wxGoodsGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaGoodsService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsGet -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 兑换商品接口
     * @param id
     * @param request
     * @return
     */
    @RequestMapping(value="/wx/goods/exchange/{id}",method= RequestMethod.POST)
    public ResponseBean wxExchangeGoods(@PathVariable Integer id, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            String openid = JWTUtils.getSubject(request);
            //兑换商品
            String state = iTaGoodsService.exchangeGoods(id,openid);
            if (state.equals(CommConstant.SUCCESS)){
                responseBean.addSuccess("兑换成功");
            }else{
                responseBean.addError(state);
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taGoodsGet -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
