package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaMiniapp;
import com.huiju.estateagents.service.ITaMiniappService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 小程序表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-11
 */
@RestController
@RequestMapping("/")
public class TaMiniappController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMiniappController.class);

    @Autowired
    public ITaMiniappService iTaMiniappService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/center/taMiniapp",method= RequestMethod.GET)
    public ResponseBean taMiniappList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaMiniapp> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaMiniapp> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaMiniapp> result = iTaMiniappService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMiniappList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taMiniapp 实体对象
     * @return
     */
    @RequestMapping(value="/center/taMiniapp",method= RequestMethod.POST)
    public ResponseBean taMiniappAdd(@RequestBody TaMiniapp taMiniapp){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaMiniappService.save(taMiniapp)){
                responseBean.addSuccess(taMiniapp);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMiniappAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taMiniapp/{id}", method= RequestMethod.DELETE)
    public ResponseBean taMiniappDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaMiniappService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMiniappDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taMiniapp 实体对象
     * @return
     */
    @RequestMapping(value="/center/taMiniapp/{id}",method= RequestMethod.PUT)
    public ResponseBean taMiniappUpdate(@PathVariable String id,
                                        @RequestBody TaMiniapp taMiniapp){
        ResponseBean responseBean = new ResponseBean();
        try {
            taMiniapp.setMiniappId(id);
            if (iTaMiniappService.updateById(taMiniapp)){
                responseBean.addSuccess(taMiniapp);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMiniappUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/center/taMiniapp/{id}",method= RequestMethod.GET)
    public ResponseBean taMiniappGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaMiniappService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMiniappDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
