package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.entity.TaNews;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.service.ITaBuildingService;
import com.huiju.estateagents.service.ITaNewsService;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.ITaSaveService;
import org.checkerframework.checker.units.qual.A;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
    * 资讯表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class TaNewsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaNewsController.class);

    @Autowired
    public ITaNewsService iTaNewsService;

    @Autowired
    public ITaPersonService iTaPersonService;

    @Autowired
    public ITaSaveService iTaSaveService;

    @Autowired
    public ITaBuildingService iTaBuildingService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taNews",method= RequestMethod.GET)
    public ResponseBean taNewsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @RequestParam(value = "buildingId", required = false) String buildingId,
                                   @RequestParam(value = "orgId", required = false) Integer orgId,
                                   @RequestParam(value = "newsTypeId", required = false) Integer newsTypeId,
                                   @RequestParam(value = "newsStatus", required = false) Integer newsStatus){
        ResponseBean responseBean = iTaNewsService.getList(pageNum, pageSize, buildingId, orgId, newsTypeId, newsStatus);
        return responseBean;
    }

    /**
     * 微信 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/taNews",method= RequestMethod.GET)
    public ResponseBean wxTaNewsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                     @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @RequestParam(required = false) String buildingId,
                                     @RequestParam(required = false) Integer cityId,
                                     @RequestParam(defaultValue = "false") Boolean mine,
                                     HttpServletRequest request
    ){
        List<String> targets = new ArrayList<>();
        if (null != mine && mine) {
            String openid = JWTUtils.getSubject(request);
            List<TaPerson> persons = iTaPersonService.getPersonsByOpenId(openid);
            if (null == persons || persons.size() == 0) {
                return ResponseBean.error("当前账户信息异常, 清除缓存重试", ResponseBean.ERROR_UNAVAILABLE);
            }

            targets = iTaSaveService.getTargesOfPerson(persons.get(0).getPersonId(), CommConstant.FAVOR_NEWS);
        }

        IPage<TaNews> results = iTaNewsService.getWxList(pageNum, pageSize, buildingId, targets,cityId,mine);
        return ResponseBean.success(results);
    }

    /**
     * 保存对象
     * @param taNews 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taNews",method= RequestMethod.POST)
    public ResponseBean taNewsAdd(@RequestBody TaNews taNews){
        Integer cityId = iTaBuildingService.getCityById(taNews.getBuildingId());
        taNews.setCityId(cityId);
        ResponseBean responseBean = iTaNewsService.addTaNews(taNews);
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/taNews/{id}", method= RequestMethod.DELETE)
    public ResponseBean taNewsDelete(@PathVariable Integer id){
        ResponseBean responseBean = iTaNewsService.deleteTaNews(id);
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taNews 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taNews/{id}",method= RequestMethod.PUT)
    public ResponseBean taNewsUpdate(@PathVariable Integer id,
                                        @RequestBody TaNews taNews){
        taNews.setNewsId(id);
        Integer cityId = iTaBuildingService.getCityById(taNews.getBuildingId());
        taNews.setCityId(cityId);
        ResponseBean responseBean = iTaNewsService.updateTaNews(taNews);
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taNews/{id}",method= RequestMethod.GET)
    public ResponseBean taNewsGet(@PathVariable Integer id){
        ResponseBean responseBean = iTaNewsService.getTaNewsById(id);
        return responseBean;
    }

    /**
     * 微信 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/taNews/{id}",method= RequestMethod.GET)
    public ResponseBean wxTaNewsGet(@PathVariable Integer id,HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> persons = iTaPersonService.getPersonsByOpenId(openid);
        if (null == persons || persons.size() == 0) {
            return ResponseBean.error("当前账户信息异常, 清除缓存重试", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = persons.get(0);
        ResponseBean responseBean = iTaNewsService.getWxTaNewsById(id,person.getPersonId());
        return responseBean;
    }

    /**
     * 微信 资讯阅读量+1
     * @param id
     * @return
     */
    @RequestMapping(value = "/wx/taNews/pvNum/{id}", method = RequestMethod.PUT)
    public ResponseBean wxTaPvNum(@PathVariable Integer id) {
        ResponseBean responseBean = iTaNewsService.wxTaPvNum(id);
        return responseBean;
    }
}
