package com.huiju.estateagents.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.entity.TaBuildingDynamic;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaPersonBuilding;
import com.huiju.estateagents.service.ITaPersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.huiju.estateagents.base.BaseController;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 人员表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@RestController
@RequestMapping("/api")
public class TaPersonController extends BaseController {
    @Autowired
    ITaPersonService taPersonService;

    /**
     *
     *  因为人员表是集合系统的所有种类的用户，包含了各种角色。因此各种角色的操作都在本 controller 中完成
     *  以下是置业顾问卡片内容
     *
     */

    /**
     * 获取卡片列表
     * @param pageNumber
     * @param pageSize
     * @return
     */
    @GetMapping("/wx/cards")
    public ResponseBean getCardList(@RequestParam(defaultValue = "1") int pageNumber,
                                    @RequestParam(defaultValue = "10") int pageSize,
                                    @RequestParam(defaultValue = "false") boolean mine,
                                    @RequestParam(value = "buildingId", required = false)String buildingId,
                                    HttpServletRequest request) {
        if (pageNumber < 0 || pageSize < 0) {
            return ResponseBean.error("分页参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        if (mine){
            String openid = JWTUtils.getSubject(request);
            List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
            if (null == taPersons || taPersons.size() != 1) {
                return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
            }
            TaPerson person = taPersons.get(0);
            IPage<Map<String, Object>>  result = taPersonService.getSavedConsaultants(pageNumber,pageSize,person.getPersonId());
            return ResponseBean.success(result);
        }else {
            IPage<Map<String, Object>> result = taPersonService.getCardList(pageNumber, pageSize,buildingId);
            return ResponseBean.success(result);
        }


    }

    /**
     * 绑定卡片
     * @param paramStr
     * @return
     */
    @PostMapping("/wx/cards/apply")
    public ResponseBean applyCard(@RequestBody String paramStr, HttpServletRequest request) {
        JSONObject params = JSONObject.parseObject(paramStr);
        String phone = (String) params.get("phone");
        String pass = (String) params.get("pass");
        String openid = JWTUtils.getSubject(request);

        if (isEmpty(phone) || isEmpty(pass)) {
            return ResponseBean.error("参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        ResponseBean resp = taPersonService.checkPhoneAndPass(phone, pass);

        // 成功返回空数据
        if (resp.getCode() != ResponseBean.CODE_SUCCESS) {
            return resp;
        }

        return taPersonService.bindCard(phone, pass, openid);
    }

    /**
     * 获取名片详情
     * @param id
     * @return
     */
    @GetMapping("/wx/cards/{id}")
    public ResponseBean getCardDetail(@PathVariable String id, HttpServletRequest request) {
        if (isEmpty(id)) {
            return ResponseBean.error("参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);

        return taPersonService.getCardDetail(openid, id,person.getPersonId());
    }

    /**
     * 找回密码
     * @param plat 平台类型 wx 是微信相关, admin 是后台管理系统
     * @param paramStr
     * @return
     */
    @PostMapping("/{plat}/resetPass")
    public ResponseBean resetPassword(@PathVariable String plat, @RequestBody String paramStr) {
        JSONObject params = JSONObject.parseObject(paramStr);
        String phone = (String) params.get("phone");
        String code = (String) params.get("code");
        String pass = (String) params.get("pass");

        if (isEmpty(phone) || isEmpty(code) || isEmpty(pass)) {
            return ResponseBean.error("参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // todo
        // 验证 验证码是否正确
        if (code != "1234") {
            return ResponseBean.error("验证码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return taPersonService.resetPassword(phone, pass, plat);
    }


    /**
     *
     *  以下是经纪人部分
     *
     */


    /**
     * 注册经纪人
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/register")
    public ResponseBean resgiteAgent(@RequestBody String paramStr, HttpServletRequest request) {
        JSONObject params = JSONObject.parseObject(paramStr);
        String name = (String) params.get("name");
        String phone = (String) params.get("phone");
        Integer sex = (Integer) params.get("sex");
        String explain = (String) params.get("explain");

        if (isEmpty(name) || isEmpty(phone) || isEmpty(explain)) {
            return ResponseBean.error("请检查部分参数不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 当前人员
        String openid = JWTUtils.getSubject(request);

        return taPersonService.resgiteAgent(name, phone, sex, explain, openid);
    }

    /**
     * 生成海报
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/poster")
    public ResponseBean genPoster(@RequestBody String paramStr, HttpServletRequest request) {
        return null;
    }


    /**
     *
     * 以下是个人中心部分
     *
     */

    /**
     * 获取个人信息
     * @param request
     * @return
     */
    @GetMapping("/wx/user/info")
    public ResponseBean getUserInfo(HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);

        return taPersonService.getWxUser(openid);
    }

    /**
     * 个人签到
     * @param request
     * @return
     */
    @PostMapping("/wx/user/signin")
    public ResponseBean userSign(HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);

        return taPersonService.getWxUserSign(openid);
    }


    /**
     *
     *
     *  以下是系统用户管理
     *
     */

    /**
     * 用户手机号登录
     * @param paramStr
     * @return
     */
    @PostMapping("/admin/signin")
    public ResponseBean signin(@RequestBody String paramStr) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (params == null) {
            return ResponseBean.error("非法参数", ResponseBean.ERROR_MISSING_PARAMS);
        }

        String userPhone = params.getString("phone");
        String userCaptcha = params.getString("captcha");

        // todo
        if (!"1234".equals(userCaptcha)) {
            return ResponseBean.error("验证码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = taPersonService.getPersonByTel(userPhone);
        if (taPerson == null) {
            return ResponseBean.error("手机号不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (taPerson.getStatus() != CommConstant.STATUS_NORMAL) {
            return ResponseBean.error("用户状态异常", ResponseBean.ERROR_UNAVAILABLE);
        }

        String token = JWTUtils.newToken(taPerson.getPersonId());

        Map<String, Object> result = new HashMap<>();
        result.put("token", token);
        result.put("person", taPerson);

        return ResponseBean.success(result);
    }

    /**
     * 获取当前用户
     * @param request
     * @return
     */
    @GetMapping("/admin/user/current")
    public ResponseBean getCurrentPerson(HttpServletRequest request) {
        String personId = JWTUtils.getSubject(request);
        TaPerson taPerson = taPersonService.getById(personId);
        if (null == taPerson || taPerson.getStatus() != CommConstant.STATUS_NORMAL) {
            return ResponseBean.error("用户状态异常", ResponseBean.ERROR_AUTH_EXPIRED);
        }

        return ResponseBean.success(taPerson);
    }

    @GetMapping("/admin/consultant")
    public ResponseBean getConsultantList(
            Integer pageNumber,
            Integer pageSize,
            String name,
            String phone,
            Integer status,
            String buildingId,
            String personTags
    ) {
        if (null == pageNumber) pageNumber = 1;
        if (null == pageSize) pageSize = 10;

        IPage<TaPerson> taPersonIPage = taPersonService.getPersonList(pageNumber, pageSize, CommConstant.PERSON_REALTY_CONSULTANT, name, phone,status,buildingId,personTags);
        return ResponseBean.success(taPersonIPage);
    }

    @GetMapping("/admin/consultant/{id}")
    public ResponseBean getConsultant(@PathVariable String id) {
        TaPerson taPerson = taPersonService.getById(id);

        List<TaPersonBuilding> buildings = taPersonService.getPersonBuildings(id);
        if (null != buildings && buildings.size() > 0) {
            List<String> projects = new ArrayList<>();
            for (TaPersonBuilding b : buildings) {
                projects.add(b.getBuildingId());
            }
            taPerson.setProjects(projects);
        }

        return ResponseBean.success(taPerson);
    }

    @PostMapping("/admin/consultant")
    public ResponseBean newConsultant(@RequestBody String paramStr) {
        return taPersonService.newConsultant(paramStr);
    }

    @PutMapping("/admin/consultant/{id}")
    public ResponseBean editConsultant(@PathVariable String id, @RequestBody String paramStr) {
        return taPersonService.editConsultant(id, paramStr);
    }

    boolean isEmpty(String str) {
        return null == str || "".equals(str.trim());
    }

    /**
//     * 获取收藏置业顾问列表
//     * @param pageNumber
//     * @param pageSize
//     * @return
//     */
//    @GetMapping("/wx/savedPerson")
//    public ResponseBean getSavedConsaultants(@RequestParam(defaultValue = "1") int pageNumber,
//                                    @RequestParam(defaultValue = "10") int pageSize,HttpServletRequest request) {
//        String openid = JWTUtils.getSubject(request);
//        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
//        if (null == taPersons || taPersons.size() != 1) {
//            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
//        }
//        TaPerson person = taPersons.get(0);
//        if (pageNumber < 0 || pageSize < 0) {
//            return ResponseBean.error("分页参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
//        }
//        try {
//            IPage<TaPerson> result = taPersonService.getSavedConsaultants(pageNumber,pageSize,person.getPersonId());
//            return ResponseBean.success(result);
//        }catch (Exception e){
//            e.printStackTrace();
//            return ResponseBean.error("查询失败", ResponseBean.ERROR_UNAVAILABLE);
//        }
//
//    }



}
