package com.huiju.estateagents.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaRecommendCustomer;
import com.huiju.estateagents.event.EventBus;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.ITaRecommendCustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.web.bind.annotation.*;

import com.huiju.estateagents.base.BaseController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
 * 推荐客户表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@RestController
@RequestMapping("/api")
public class TaRecommendCustomerController extends BaseController {

    @Autowired
    ITaRecommendCustomerService taRecommendCustomerService;

    @Autowired
    ITaPersonService taPersonService;

    @Resource
    private ApplicationContext applicationContext;

    /**
     * 我的客户列表
     * @param pageNumber
     * @param pageSize
     * @param keywords
     * @param request
     * @return
     */
    @GetMapping("/wx/customer/list")
    public ResponseBean getMyCustList(@RequestParam int pageNumber, @RequestParam int pageSize, String keywords, HttpServletRequest request) {
        if (pageNumber < 0 || pageSize < 0) {
            return ResponseBean.error("分页参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String openid = JWTUtils.getSubject(request);
        return taRecommendCustomerService.getMyCustList(openid, keywords, pageNumber, pageSize);
    }

    /**
     * 客户详情
     * @param id
     * @return
     */
    @GetMapping("/wx/customer/{id}")
    public ResponseBean getCustDetail(@PathVariable String id) {
        if (null == id || "".equals(id.trim())) {
            return ResponseBean.error("请求地址错误", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return taRecommendCustomerService.getCustDetail(id);
    }

    /**
     * 客户编辑
     * @param paramStr
     * @return
     */
    @PostMapping("/wx/customer/edit")
    public ResponseBean updateCust(@RequestBody String paramStr) {
        return taRecommendCustomerService.updateCustByJSON(paramStr);
    }

    /**
     * 推荐客户
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/customer/new")
    public ResponseBean recommendCust(@RequestBody String paramStr, HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);
        return taRecommendCustomerService.recommendCust(paramStr, openid);
    }

    /**
     * 报备客户
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/customer/report")
    public ResponseBean reportCust(@RequestBody String paramStr, HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);
        return taRecommendCustomerService.reportCust(paramStr, openid);
    }

    @PostMapping("/wx/customer/recommend")
    public ResponseBean getUnSignedCustomerList ( @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                                  @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                                  @RequestParam(value ="buildingId") String buildingId,
                                                  HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        try{
            return ResponseBean.success(taRecommendCustomerService.getUnSignedCustomerList(pageNumber,pageSize,buildingId,person.getPersonId()));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    @GetMapping("/wx/customer/myReport")
    public ResponseBean getCustomerIReport (@RequestParam(value ="personId") String personId,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try{
            IPage<TaRecommendCustomer>pg = new Page<>(pageNumber,pageSize);
            QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("realty_consultant",personId);
            queryWrapper.eq("report_recommend_status",CommConstant.REPORTED);
            queryWrapper.orderByDesc("create_date");
            IPage<TaRecommendCustomer>result = taRecommendCustomerService.page(pg,queryWrapper);
            return ResponseBean.success(result);
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    // 客户列表
    @GetMapping("/admin/customer/recommend")
    public ResponseBean getCustomerList (@RequestParam(value ="name",required = false) String name,
                                         @RequestParam(value ="tel",required = false) String tel,
                                         @RequestParam(value ="buildingId",required = false) String buildingId,
                                         @RequestParam(value ="consultName",required = false) String consultName,
                                         @RequestParam(value ="consultTel",required = false) String consultTel,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="entryType",required = false) String entryType,
                                         @RequestParam(value ="verifyStatus",required = false) String verifyStatus,
                                         @RequestParam(value = "sex",required = false)Integer sex){
        try{
            return ResponseBean.success(taRecommendCustomerService.getCustomerList(pageNumber,pageSize,buildingId,name,tel,consultName,consultTel,entryType,verifyStatus,sex));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    //推荐客户列表
    @GetMapping("/admin/customer/recommend/recommender")
    public ResponseBean getRecCustomerList (@RequestParam(value ="name",required = false) String name,
                                         @RequestParam(value ="tel",required = false) String tel,
                                         @RequestParam(value ="buildingId",required = false) String buildingId,
                                         @RequestParam(value ="recommendName",required = false) String recommendName,
                                         @RequestParam(value ="recommendTel",required = false) String recommendTel,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="entryType",required = false) String entryType,
                                         @RequestParam(value ="verifyStatus",required = false) String verifyStatus,
                                         @RequestParam(value = "sex",required = false)Integer sex){
        try{
            return ResponseBean.success(taRecommendCustomerService.getRecCustomerList(pageNumber,pageSize,buildingId,name,tel,recommendName,recommendTel,entryType,verifyStatus,sex));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    //报备客户列表
    @GetMapping("/admin/customer/recommend/report")
    public ResponseBean getRepCustomerList (@RequestParam(value ="name",required = false) String name,
                                         @RequestParam(value ="tel",required = false) String tel,
                                         @RequestParam(value ="buildingId",required = false) String buildingId,
                                         @RequestParam(value ="consultName",required = false) String consultName,
                                         @RequestParam(value ="consultTel",required = false) String consultTel,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="entryType",required = false) String entryType,
                                         @RequestParam(value ="verifyStatus",required = false) String verifyStatus,
                                         @RequestParam(value = "sex",required = false)Integer sex, HttpServletRequest request){
        String personId = JWTUtils.getSubject(request);
        TaPerson taPerson = taPersonService.getById(personId);
        try{
            return ResponseBean.success(taRecommendCustomerService.getRepCustomerList(pageNumber,pageSize,buildingId,name,tel,consultName,consultTel,entryType,verifyStatus,sex));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    //独立经纪人列表
    @GetMapping("/admin/customer/agents")
    public ResponseBean getIndependentAgents (@RequestParam(value ="name",required = false) String name,
                                            @RequestParam(value ="tel",required = false) String tel,
                                            @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try{
            return ResponseBean.success(taRecommendCustomerService.getIndependentAgents(pageNumber,pageSize,name,tel));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    @GetMapping("/admin/customer/recommend/{customerId}")
    public ResponseBean getCustomersIRecommended (@RequestParam int pageNumber, @RequestParam int pageSize, @PathVariable String customerId){
        String buildingId="";
        try{
            return ResponseBean.success(taRecommendCustomerService.getCustomersIRecommended(pageNumber,pageSize,customerId,buildingId));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

        /**
     * 修改对象
     * @param taRecommendCustomer 实体对象
     * @return
     */
    @RequestMapping(value="/wx/customer/recommend/edit/{id}",method= RequestMethod.PUT)
    public ResponseBean taRecommendCustomerUpdateWx(@PathVariable String id,
                                        @RequestBody TaRecommendCustomer taRecommendCustomer){
        ResponseBean responseBean = new ResponseBean();
        taRecommendCustomer.setCustomerId(id);
        try {
            if (taRecommendCustomerService.updateById(taRecommendCustomer)){
                responseBean.addSuccess(taRecommendCustomer);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    /**
     * 修改对象
     * @param taRecommendCustomer 实体对象
     * @return
     */
    @RequestMapping(value="/admin/customer/recommend/edit/{id}",method= RequestMethod.PUT)
    public ResponseBean taRecommendCustomerUpdate(@PathVariable String id,
                                                  @RequestBody TaRecommendCustomer taRecommendCustomer){
        ResponseBean responseBean = new ResponseBean();
        taRecommendCustomer.setCustomerId(id);
        try {
            if (taRecommendCustomerService.updateById(taRecommendCustomer)){
                responseBean.addSuccess(taRecommendCustomer);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @RequestMapping(value = "/wx/customer/recommend/get/{id}", method = RequestMethod.GET)
    public ResponseBean getSingleCustomer(@PathVariable(value = "id") String customerId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taRecommendCustomerService.getById(customerId));
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    @RequestMapping(value = "/admin/customer/recommend/getById/{id}", method = RequestMethod.GET)
    public ResponseBean getRecommendCustomerById(@PathVariable(value = "id") String customerId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taRecommendCustomerService.getCustomerById(customerId));
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    @GetMapping(value = "/admin/customer/recommend/get/{id}")
    public ResponseBean getCutomerDetail(@PathVariable String id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taRecommendCustomerService.getCustomerDetail(id));
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @GetMapping("/admin/customer/recommend/drift")
    public ResponseBean getDriftCustomerList (@RequestParam(value ="buildingId",defaultValue = "false") String buildingId,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try{
            return ResponseBean.success(taPersonService.getDriftCustomerList(pageNumber,pageSize,buildingId));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @return
     */
    @RequestMapping(value="/admin/customer/recommend/verify/{id}",method= RequestMethod.PUT)
    public ResponseBean taRecommendCustomerVerify(@PathVariable String id,@RequestParam Integer verifyStatus, @RequestParam(required = false) String verifyRemark){
        if (null == verifyStatus) {
            return ResponseBean.error("审核结果非法", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        ResponseBean responseBean = new ResponseBean();
        try {
            TaRecommendCustomer taRecommendCustomer = taRecommendCustomerService.getById(id);
            if(taRecommendCustomer.getVerifyStatus().equals(CommConstant.VERIFY_READY) ){
                taRecommendCustomer.setVerifyStatus(verifyStatus);
                if(!StringUtils.isEmpty(verifyRemark)){
                    taRecommendCustomer.setVerifyRemark(verifyRemark);
                }
                if (taRecommendCustomerService.updateById(taRecommendCustomer)){

                    // 审核通过增加积分
                    if (CommConstant.VERIFY_AGREE == verifyStatus) {
                        applicationContext.publishEvent(new EventBus(taRecommendCustomer, EventBus.EventType.RecommendCustomer));
                    }

                    responseBean.addSuccess(taRecommendCustomer);
                }else {
                    responseBean.addError("fail");
                }
            } else {
                responseBean.addSuccess("客户已审核");
            }

        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

}
