package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TdBuildingType;
import com.huiju.estateagents.service.ITdBuildingTypeService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import com.huiju.estateagents.base.BaseController;

/**
 * <p>
    * 项目类型字典表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-29
 */
@RestController
@RequestMapping("/api")
public class TdBuildingTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdBuildingTypeController.class);

    @Autowired
    public ITdBuildingTypeService iTdBuildingTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/tdBuildingType",method= RequestMethod.GET)
    public ResponseBean tdBuildingTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TdBuildingType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdBuildingType> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("status", 1);
            queryWrapper.orderByDesc("create_date");

            IPage<TdBuildingType> result = iTdBuildingTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("tdBuildingTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/tdBuildingType",method= RequestMethod.GET)
    public ResponseBean tdWxBuildingTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TdBuildingType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdBuildingType> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("status", 1);
            queryWrapper.orderByDesc("create_date");

            IPage<TdBuildingType> result = iTdBuildingTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("tdBuildingTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    /**
     * 保存对象
     * @param tdBuildingType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/tdBuildingType",method= RequestMethod.POST)
    public ResponseBean tdBuildingTypeAdd(@RequestBody TdBuildingType tdBuildingType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdBuildingTypeService.save(tdBuildingType)){
                responseBean.addSuccess(tdBuildingType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdBuildingTypeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/tdBuildingType/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdBuildingTypeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTdBuildingTypeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdBuildingTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdBuildingType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/tdBuildingType/{id}",method= RequestMethod.PUT)
    public ResponseBean tdBuildingTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TdBuildingType tdBuildingType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdBuildingTypeService.updateById(tdBuildingType)){
                responseBean.addSuccess(tdBuildingType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdBuildingTypeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/tdBuildingType/{id}",method= RequestMethod.GET)
    public ResponseBean tdBuildingTypeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTdBuildingTypeService.getById(id));
        }catch (Exception e){
            logger.error("tdBuildingTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
