package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TdCity;
import com.huiju.estateagents.service.ITdCityService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import com.huiju.estateagents.base.BaseController;

import java.util.List;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-07
 */
@RestController
@RequestMapping("/api")
public class TdCityController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdCityController.class);

    @Autowired
    public ITdCityService iTdCityService;


    /**
     * 查询列表
     * @return
     */
    @RequestMapping(value="/admin/tdCity",method= RequestMethod.GET)
    public ResponseBean tdCityList(@RequestParam(value = "leveltype", required = false) String leveltype){
        ResponseBean responseBean = new ResponseBean();
        try {
            List<TdCity> result = iTdCityService.selectCity(leveltype,"");
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("tdCityList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 查询列表
     * @return
     */
    @RequestMapping(value="/wx/tdCity",method= RequestMethod.GET)
    public ResponseBean tdCityListWx(@RequestParam(value = "leveltype", required = false) String leveltype){
        ResponseBean responseBean = new ResponseBean();
        try {
            List<TdCity> result = iTdCityService.selectCity(leveltype, "1");
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("tdCityList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param tdCity 实体对象
     * @return
     */
    @RequestMapping(value="/tdCity",method= RequestMethod.POST)
    public ResponseBean tdCityAdd(@RequestBody TdCity tdCity){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdCityService.save(tdCity)){
                responseBean.addSuccess(tdCity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdCityAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdCity/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdCityDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTdCityService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdCityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param tdCity 实体对象
     * @return
     */
    @RequestMapping(value="/edit/tdCity/",method= RequestMethod.PUT)
    public ResponseBean tdCityUpdate(@PathVariable List<TdCity> cities,
                                        @RequestBody TdCity tdCity){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdCityService.updateBatchById(cities)){
                responseBean.addSuccess(tdCity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdCityUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdCity/{id}",method= RequestMethod.GET)
    public ResponseBean tdCityGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTdCityService.getById(id));
        }catch (Exception e){
            logger.error("tdCityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
