package com.huiju.estateagents.interceptor;

import com.alibaba.fastjson.JSONObject;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.sysUser.entity.SysToken;
import com.huiju.estateagents.center.sysUser.service.ISysTokenService;
import com.huiju.estateagents.common.JWTUtils;
import io.jsonwebtoken.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@Component
public class AccessInterceptor implements HandlerInterceptor {
    
    @Autowired
    private ISysTokenService sysTokenService;
    
    private String[] whiteList = {
            "/wx/chat", // 聊天暂时不鉴权
            "/api/wx/login",
            "/api/wx/tdCity",
            "/api/admin/signin",
            "/api/taCheckin/activity",
            "/api/wx/qrcode/scene",
		    "/api/center/signin",
    };

    /*
     * 视图渲染之后的操作
     */
    @Override
    public void afterCompletion(HttpServletRequest arg0, HttpServletResponse arg1, Object arg2, Exception arg3)
            throws Exception {

    }

    /*
     * 处理请求完成后视图渲染之前的处理操作
     */
    @Override
    public void postHandle(HttpServletRequest arg0, HttpServletResponse arg1, Object arg2, ModelAndView arg3)
            throws Exception {

    }

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object obj) throws Exception {
        // 白名单跳过
        if (inWhiteList(request)) {
            return true;
        }

        // 微信头必须对
        if (!checkMiniApp(request)) {
            ResponseBean resp = ResponseBean.error("请使用微信请求接口", ResponseBean.ERROR_ILLEGAL_PARAMS);

            response.addHeader("Content-type", "application/json");
            response.getOutputStream().write(JSONObject.toJSONBytes(resp));
            return false;
        }

        // 消息头必须包含 authorization 字段
        String jwtHeader = request.getHeader("authorization");
        if (null == jwtHeader || "".equals(jwtHeader)) {
            ResponseBean resp = ResponseBean.error("请先进行系统登录操作", ResponseBean.ERROR_AUTH_FAIL);

            response.addHeader("Content-type", "application/json");
            response.getOutputStream().write(JSONObject.toJSONBytes(resp));
            return false;
        }

        String[] jwtAuths = jwtHeader.split("Bearer ");
        if (null == jwtAuths || jwtAuths.length < 2) {
            ResponseBean resp = ResponseBean.error("权限验证非法, 数据格式不正确", ResponseBean.ERROR_AUTH_FAIL);

            response.addHeader("Content-type", "application/json");
            response.getOutputStream().write(JSONObject.toJSONBytes(resp));
            return false;
        }

        try {
            // 只尝试去解析
            Jwts.parser().setSigningKey(JWTUtils.key).parseClaimsJws(jwtAuths[1]);
        } catch (ExpiredJwtException e) {
            ResponseBean resp = ResponseBean.error("权限验证非法, Token 已过期", ResponseBean.ERROR_AUTH_EXPIRED);
            response.addHeader("Content-type", "application/json");
            response.getOutputStream().write(JSONObject.toJSONBytes(resp));
            return false;

        } catch (JwtException e) {
            ResponseBean resp = ResponseBean.error("权限验证非法, " + e.getMessage(), ResponseBean.ERROR_AUTH_FAIL);


            response.addHeader("Content-type", "application/json");
            response.getOutputStream().write(JSONObject.toJSONBytes(resp));
            return false;
        }
        
        //添加如果执行了登出操作提示先进行登录
        SysToken sysToken = sysTokenService.getById(jwtAuths[1]);
        if (null == sysToken){
            ResponseBean resp = ResponseBean.error("请先进行系统登录操作", ResponseBean.ERROR_AUTH_FAIL);
    
            response.addHeader("Content-type", "application/json");
            response.getOutputStream().write(JSONObject.toJSONBytes(resp));
            return false;
        }
        
        return true;
    }

    private boolean checkMiniApp(HttpServletRequest request) {
        String requestURI = request.getRequestURI();

        // 非微信请求
        if (!requestURI.startsWith("/api/wx")) {
            return true;
        }

        String ua = request.getHeader("user-agent");
        return ua.contains("micromessenger") || ua.contains("MicroMessenger");
    }

    private boolean inWhiteList(HttpServletRequest request) {
        String requestURI = request.getRequestURI();

        for (String it : whiteList) {
            if (requestURI.startsWith(it)) {
                return true;
            }
        }

        return false;
    }
}
