package com.huiju.estateagents.mapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.huiju.estateagents.entity.TaChannel;
import com.huiju.estateagents.entity.TaPerson;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.huiju.estateagents.po.PersonPO;
import org.apache.ibatis.annotations.*;

import java.io.Serializable;
import java.time.LocalDate;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 人员表 Mapper 接口
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@Mapper
public interface TaPersonMapper extends BaseMapper<TaPerson> {
    List<Map<String,Object>> selectCardList(IPage<Map<String,Object>> page, @Param("personType") String personType, @Param("status") int status,@Param("buildingId")String buildingId);

    int setFieldIncrement(@Param("personId") String personId, @Param("field") String field, @Param("increment") int increment);

    TaPerson getSalesExecutive();

    List<TaPerson> getPersonByOpenId(@Param("openId") String openId);

    List<Map<String, Object>> selectBuildingConsultants(@Param("buildingId") String buildingId, @Param("personType") String personType, @Param("status") int status);

    IPage<TaPerson> selectCustomer(IPage<TaPerson> page);

    TaPerson getById(@Param("personId") String personId);


    List<String>getUserProjects(@Param("personId") String personId);

    TaPerson selectByIdPerson(@Param("openid") String openid);

    List<String> getConsultantByName(@Param("name")String name);

    String getConsultantByTel(@Param("tel")String tel);

    List<Map<String,Object>> selectCardListofMine(IPage<Map<String,Object>> page, @Param("personType") String personType, @Param("status") int status,@Param("personIds")List<String> personIds);

    //---------- 用户总数 start ------------

    /**
     * 总用户数
     * @param personType
     * @return
     */
    @ResultType(Integer.class)
    @Select("select count(1) from ta_person where ifnull(person_type, '') != #{personType}")
    Integer selectUserCount(@Param("personType") String personType);

    /**
     * 总注册数
     * @param personType
     * @return
     */
    @ResultType(Integer.class)
    @Select("select count(1) from ta_person where ifnull(person_type, '') != #{personType} and phone is not null")
    Integer selectRegisteredCount(@Param("personType") String personType);

    /**
     * 根据时间段查询
     * @param personType
     * @return
     */
    Integer selectRecentlyCount(@Param("personType") String personType, @Param("startDate")LocalDate startDate, @Param("endDate")LocalDate endDate);

    //---------- 用户总数 end ------------

    /**
     * 用户行为
     * @param personType
     * @param startDate
     * @param endDate
     * @return
     */
    List<PersonPO> selectUserBehavior(@Param("personType") String personType,
                                      @Param("startDate")LocalDate startDate,
                                      @Param("endDate")LocalDate endDate,
                                      @Param("buildingId") String buildingId,
                                      @Param("eventType") String eventType,
                                      @Param("event") String event,
                                      @Param("activity") String activity);

    /**
     * 活跃用户数 / 最近新增的用户数
     * @param personType
     * @param dateType
     * @return
     */
    List<Map<String, Object>> selectActiveUserCount(@Param("personType") String personType, @Param("dateType") String dateType, @Param("startDate")LocalDate startDate, @Param("endDate")LocalDate endDate);

    /**
     * 新增用户数
     * @param personType
     * @param startDate
     * @param endDate
     * @return
     */
    List<Map<String, Object>> selectNewsUserCount(@Param("personType") String personType, @Param("startDate")LocalDate startDate, @Param("endDate")LocalDate endDate);

    /**
     * 性别比例
     *
     *  据说 1 男  2 女
     *
     * @param personType
     * @return
     */
    @Select("select count(1) as sex_count from ta_person where ifnull(person_type, '') != #{personType} and gender = #{gender}")
    Integer selectSexUser(@Param("personType") String personType, @Param("gender") Integer gender);


    /**
     * 城市比例
     * @param personType
     * @return
     */
    @ResultType(Map.class)
    @Select("SELECT " +
            "ifnull(b.NAME, '其他') AS city, " +
            "count(a.person_id) AS city_count " +
            " FROM" +
            " ta_person a" +
            " LEFT JOIN ( select t.*, s.pinyin as province from td_city t JOIN td_city s on t.parentid = s.id) b ON a.city = b.pinyin and a.province = b.province where ifnull(a.person_type, '') != #{personType} and a.city is not null GROUP BY a.city")
    List<Map<String, Object>> selectCityUser(@Param("personType") String personType);


    // ------------- 用户来源 start ------------

    /**
     * 用户来源 的饼图
     * @param recommendPersonType
     * @return
     */
    Integer selectUserSourcePie(@Param("recommendPersonType") String recommendPersonType, @Param("personType") String personType);

    /**
     * 用户来源 柱状
     * @return
     */
    List<Map<String, Object>> selectUserSourceColumnar(@Param("personType") String personType, @Param("startDate") LocalDate startDate, @Param("endDate")LocalDate endDate);

    /**
     * 用户来源 数据列表
     */
    List<Map<String,Object>> selectUserSourceData(@Param("personType") String personType, @Param("startDate")LocalDate startDate, @Param("endDate")LocalDate endDate);

    // ------------- 用户来源 end ------------

    @Update("UPDATE ta_person  SET ${field} = IFNULL(${field}, 0) + #{increment}  WHERE person_id = #{newsId}")
    void setFieldNum(@Param("newsId") String newsId, @Param("field") String field, @Param("increment") int increment);

    IPage<TaPerson> getPersonList(IPage<TaPerson> page, @Param("personType")String personType, @Param("name") String name, @Param("phone") String phone,@Param("status") Integer status,@Param("buildingId") String buildingId,@Param("personTags") String personTags);

    /**
     * 渠道下的经纪人
     * @param pg
     * @param name
     * @param phone
     * @return
     */
    IPage<TaPerson> channelBrokerList(IPage<TaChannel> pg, @Param("name") String name, @Param("phone") String phone);
}
