package com.huiju.estateagents.service.impl;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.bean.*;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.*;
import com.huiju.estateagents.config.WxProperties;
import com.huiju.estateagents.entity.TaMiniappQrcode;
import com.huiju.estateagents.mapper.TaMiniFormidsMapper;
import com.huiju.estateagents.mapper.TaMiniappQrcodeMapper;
import com.huiju.estateagents.service.IMiniAppService;
import com.huiju.estateagents.service.ITaMiniFormidsService;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.error.WxErrorException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class MiniAppServiceImpl implements IMiniAppService {

    @Autowired
    TaMiniappQrcodeMapper taMiniappQrcodeMapper;

    @Autowired
    TaMiniFormidsMapper taMiniFormidsMapper;

    @Autowired
    ITaMiniFormidsService taMiniFormidsService;

    @Override
    public WxMaJscode2SessionResult getSessionInfo(String code) throws WxErrorException {
        WxMaService wxService = WxUtils.getMiniApp();
        System.out.println(wxService);
        System.out.println(wxService.getUserService());
        return wxService.getUserService().getSessionInfo(code);
    }

    @Override
    public boolean checkUserInfo(String sessionKey, String rawData, String signature) {
        WxMaService wxService = WxUtils.getMiniApp();
        return wxService.getUserService().checkUserInfo(sessionKey, rawData, signature);
    }

    @Override
    public WxMaUserInfo getUserInfo(String sessionKey, String encryptedData, String iv) {
        WxMaService wxService = WxUtils.getMiniApp();
        return wxService.getUserService().getUserInfo(sessionKey, encryptedData, iv);
    }

    @Override
    public WxMaPhoneNumberInfo getPhoneNoInfo(String sessionKey, String encryptedData, String iv) {
        WxMaService wxService = WxUtils.getMiniApp();
        return wxService.getUserService().getPhoneNoInfo(sessionKey, encryptedData, iv);
    }

    @Override
    public void sendNoticeMessage(String toUser, String link, String name, String phone, String content, LocalDateTime dt) {
        List<WxMaTemplateData> data = new ArrayList<>();
        data.add(new WxMaTemplateData("keyword1", name, "#fffff"));
        data.add(new WxMaTemplateData("keyword2", phone, "#fffff"));
        data.add(new WxMaTemplateData("keyword3", content, "#fffff"));
        data.add(new WxMaTemplateData("keyword4", DateUtils.cutSecond(dt), "#fffff"));

        sendMessage("notice", toUser, link, data);
    }

    @Override
    public void sendMainBizMessage(String toUser, String link, String custName, String phone, String sex, String fromName, String bizType, String content) {
        List<WxMaTemplateData> data = new ArrayList<>();
        data.add(new WxMaTemplateData("keyword1", custName, "#fffff"));
        data.add(new WxMaTemplateData("keyword2", StringUtils.ifNull(phone, "未知"), "#fffff"));
        data.add(new WxMaTemplateData("keyword3",StringUtils.ifNull(sex, "未知"), "#fffff"));
        data.add(new WxMaTemplateData("keyword4", fromName, "#fffff"));
        data.add(new WxMaTemplateData("keyword5", bizType, "#fffff"));
        data.add(new WxMaTemplateData("keyword6", content, "#fffff"));

        sendMessage("mainbiz", toUser, link, data);
    }

    @Override
    public void sendNewCustomerMessage(String toUser, String link, String custName, String phone, String sex, String fromName) {
        List<WxMaTemplateData> data = new ArrayList<>();
        data.add(new WxMaTemplateData("keyword1", custName, "#fffff"));
        data.add(new WxMaTemplateData("keyword2", StringUtils.ifNull(phone, "未知"), "#fffff"));
        data.add(new WxMaTemplateData("keyword3",StringUtils.ifNull(sex, "未知"), "#fffff"));
        data.add(new WxMaTemplateData("keyword4", fromName, "#fffff"));

        sendMessage("newCustomer", toUser, link, data);
    }

    @Override
    public ResponseBean getQrCode(String paramsStr) {
        if (null == paramsStr) return ResponseBean.error("请指定二维码生成参数", ResponseBean.ERROR_MISSING_PARAMS);

        WxMaService wxService = WxUtils.getMiniApp();
        String appid = wxService.getWxMaConfig().getAppid();

        // 先去数据库中查询
        QueryWrapper<TaMiniappQrcode> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("appid", appid);
        queryWrapper.eq("qr_params", paramsStr);
        queryWrapper.ge("expire_date", LocalDateTime.now());
        queryWrapper.orderByDesc("create_date");
        queryWrapper.isNotNull("qr_code");
        queryWrapper.last("limit 1");

        TaMiniappQrcode taMiniappQrcode = taMiniappQrcodeMapper.selectOne(queryWrapper);
        if (null != taMiniappQrcode) {
            return ResponseBean.success(taMiniappQrcode.getQrCode());
        }

        // 如果没有找到则生成一个
        JSONObject params = JSONObject.parseObject(paramsStr);
        String scene = params.getString("scene");
        String page = StringUtils.ifNull(params.getString("page"), "");
        Integer width = params.getInteger("width");
        if (null == width) width = 430;

        Boolean autoColor = params.getBoolean("auto_color");
        if (null == autoColor) autoColor = false;

        String lineColorStr = StringUtils.ifNull(params.getString("line_color"), "{\"r\":0,\"g\":0,\"b\":0}");
        WxMaCodeLineColor lineColor = JSONObject.parseObject(lineColorStr, WxMaCodeLineColor.class);
        Boolean isHyaline = params.getBoolean("is_hyaline");
        if (null == isHyaline) isHyaline = true;

        try {

            TaMiniappQrcode taQrcode = new TaMiniappQrcode();
            taQrcode.setAppid(appid);
            taQrcode.setCreateDate(LocalDateTime.now());
            taQrcode.setExpireDate(LocalDateTime.now().plusDays(7));
            taQrcode.setQrParams(paramsStr);

            boolean success = taMiniappQrcodeMapper.insert(taQrcode) > 0;
            if (!success) {
                return ResponseBean.error("生成二维码异常", ResponseBean.ERROR_UNAVAILABLE);
            }

            // 使用ID作为场景值
            String newScene = String.valueOf(taQrcode.getSerialNo());
            System.out.println("==========生成二维码参数--->" + newScene);

            File qrFile = wxService.getQrcodeService().createWxaCodeUnlimit(newScene, page, width, autoColor, lineColor, isHyaline);
            String qrcode = AliOSSUtils.putObject(qrFile, CommConstant.ALIOSS_DEFAULT_UPLOAD);
            taQrcode.setQrCode(qrcode);
            taMiniappQrcodeMapper.updateById(taQrcode);

            return ResponseBean.success(qrcode);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseBean.error("生成二维码异常", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    @Override
    public TaMiniappQrcode getQrCodeBySerialNo(Integer id) {
        return taMiniappQrcodeMapper.selectById(id);
    }

    private void sendMessage(String tplName, String toUser, String link, List<WxMaTemplateData> data) {
        WxProperties.Tpl tpl = WxUtils.getTplByName(tplName);
        if (null == tpl) return ;

        String formid = taMiniFormidsService.getFormidBy(toUser, true);
        if (StringUtils.isEmpty(formid)) {
            log.error("發送消息失敗, 沒有有效的 formid");
            return;
        }

        WxMaTemplateMessage message = WxMaTemplateMessage.builder()
                .templateId(tpl.getId())
                .data(data)
                .formId(formid)
                .page(StringUtils.ifNull(link, CommConstant.MINIAPP_INDEX))
                .toUser(toUser)
                .build();
        try {

            WxMaService wxService = WxUtils.getMiniApp();
            wxService.getMsgService().sendTemplateMsg(message);
        } catch (WxErrorException e) {
            e.printStackTrace();
        }
    }
}
