package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.*;
import com.huiju.estateagents.mapper.*;
import com.huiju.estateagents.service.ITaBuildingService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jodd.util.CollectionUtil;
import org.apache.commons.collections.CollectionUtils;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 项目表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@Service
public class TaBuildingServiceImpl extends ServiceImpl<TaBuildingMapper, TaBuilding> implements ITaBuildingService {
    @Autowired
    TaBuildingMapper taBuildingMapper;

    @Autowired
    TaBuildingImgMapper taBuildingImgMapper;

    @Autowired
    TaBuildingTagMapper taBuildingTagMapper;

    @Autowired
    TaApartmentImgMapper taApartmentImgMapper;

    @Autowired
    TaBuildingApartmentMapper taBuildingApartmentMapper;

    @Autowired
    TaSaveMapper taSaveMapper;

    @Autowired
    TaUvMapper taUvMapper;

    @Autowired
    TaShareMapper taShareMapper;

    @Autowired
    TaPersonMapper taPersonMapper;

    @Autowired
    TdCityMapper tdCityMapper;

    @Autowired
    private TaBuildingProjectTypeMapper taBuildingProjectTypeMapper;


    @Override
    public ResponseBean buildingList(Integer pageNum, Integer pageSize, String name, String code, LocalDateTime startDate, String buildingStatus, String marketStatus, Integer cityId, Integer isMain) {
        Page<TaBuilding> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        List<TaBuilding> building = taBuildingMapper.buildingList(page, name, code,startDate,buildingStatus,marketStatus,cityId,isMain);
        page.setRecords(building);

        return ResponseBean.success(page);
    }
    @Override
    public ResponseBean buildingListSelect(Integer pageNum, Integer pageSize, String name, String code, LocalDateTime startDate, String buildingStatus, String marketStatus, Integer cityId, Integer isMain) {
        Page<TaBuilding> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        List<TaBuilding> building = taBuildingMapper.buildingListSelect(page, name, code,startDate,buildingStatus,marketStatus,cityId,isMain);
        page.setRecords(building);

        return ResponseBean.success(page);
    }

    @Override
    public ResponseBean buildingSelectId(String id) {
        // 查询基础信息
        QueryWrapper<TaBuilding> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().gt(TaBuilding::getStatus,-1);
        buildingtWrapper.lambda().eq(TaBuilding::getBuildingId,id);
        TaBuilding building = taBuildingMapper.selectOne(buildingtWrapper);

        //查询当前图片
        QueryWrapper<TaBuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", id);
        BuildingImgQueryWrapper.eq("img_type", "banner");
        List<TaBuildingImg> buildingImg = taBuildingImgMapper.selectList(BuildingImgQueryWrapper);
        building.setBuildingImg(buildingImg);

        // 查询tag
        QueryWrapper<TaBuildingTag> BuildingTagQueryWrapper = new QueryWrapper<>();
        BuildingTagQueryWrapper.eq("building_id", id);
        List<TaBuildingTag> buildingTags= taBuildingTagMapper.selectList(BuildingTagQueryWrapper);
        building.setBuildingTag(buildingTags);

        // 项目类型
        QueryWrapper<TaBuildingProjectType> buildingProjectTypeQueryWrapper = new QueryWrapper<>();
        buildingProjectTypeQueryWrapper.eq("building_id", building.getBuildingId());
        List<TaBuildingProjectType> taBuildingProjectTypes = taBuildingProjectTypeMapper.selectList(buildingProjectTypeQueryWrapper);
        building.setBuildingProjectType(taBuildingProjectTypes);

        return ResponseBean.success(building);
    }

    @Override
    public ResponseBean buildingAllSelectId(String id,String personId) {
        // 查询基础信息
        QueryWrapper<TaBuilding> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().gt(TaBuilding::getStatus,-1);
        buildingtWrapper.lambda().eq(TaBuilding::getBuildingId,id);
        TaBuilding building = taBuildingMapper.selectOne(buildingtWrapper);

        //查询当前图片
        QueryWrapper<TaBuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", id);
        BuildingImgQueryWrapper.eq("img_type", "banner");
        List<TaBuildingImg> buildingImg = taBuildingImgMapper.selectList(BuildingImgQueryWrapper);
        building.setBuildingImg(buildingImg);

        // 查询tag
        QueryWrapper<TaBuildingTag> BuildingTagQueryWrapper = new QueryWrapper<>();
        BuildingTagQueryWrapper.eq("building_id", id);
        List<TaBuildingTag> buildingTags = taBuildingTagMapper.selectList(BuildingTagQueryWrapper);
        building.setBuildingTag(buildingTags);

//        QueryWrapper<Visit> BuildingVisitQueryWrapper = new QueryWrapper<>();
//        BuildingVisitQueryWrapper.eq("visit_type", "building");
//        BuildingVisitQueryWrapper.eq("visit_content", id);
//        BuildingVisitQueryWrapper.orderByDesc("visit_date");
//        List<Visit> visits = visitMapper.selectList(BuildingVisitQueryWrapper);
//        building.setVisits(visits);

        // 查询户型
        QueryWrapper<TaBuildingApartment> AppointmentQueryWrapper = new QueryWrapper<>();
        AppointmentQueryWrapper.eq("building_id", id);
        AppointmentQueryWrapper.eq("status", 1);
        List<TaBuildingApartment> appoint = taBuildingApartmentMapper.selectList(AppointmentQueryWrapper);
        for (TaBuildingApartment apar:appoint) {
            List<TaBuildingImg> imgs = taBuildingImgMapper.getBuildingImgByApartment(apar.getApartmentId());
            apar.setBuildingImgList(imgs);
        }
        building.setBuildingApartment(appoint);

        getBuildingAttaches(building);
        QueryWrapper<TaSave> saveQueryWrapper = new QueryWrapper<>();
        saveQueryWrapper.eq("tagert_type",CommConstant.FAVOR_PROJECT);
        saveQueryWrapper.eq("person_id",personId);
        saveQueryWrapper.eq("saved_target",building.getBuildingId());
        Integer num = taSaveMapper.selectCount(saveQueryWrapper);
        if (num>0){
            building.setIsSave(CommConstant.STATUS_NORMAL);
        }else {
            building.setIsSave(CommConstant.STATUS_UNACCALIMED);
        }

        // 项目类型
        QueryWrapper<TaBuildingProjectType> projectTypeQueryWrapper = new QueryWrapper<>();
        projectTypeQueryWrapper.eq("building_id", building.getBuildingId());
        projectTypeQueryWrapper.eq("status", 1);
        List<TaBuildingProjectType> buildingProjectTypes = taBuildingProjectTypeMapper.selectList(projectTypeQueryWrapper);
        building.setBuildingProjectType(buildingProjectTypes);

        return ResponseBean.success(building);
    }

    @Override
    public ResponseBean buildingUpdate(String parameter) {
        JSONObject object= JSONObject.parseObject(parameter);

        TaBuilding building = JSONObject.parseObject(parameter,TaBuilding.class);
        String imgStr = object.getString("img");
        List<TaBuildingImg> buildingImgs = JSONObject.parseArray(imgStr, TaBuildingImg.class);

        //图片先删除再添加
        QueryWrapper<TaBuilding> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", building.getBuildingId());
        taBuildingMapper.update(building,buildingIdQueryWrapper);
        QueryWrapper<TaBuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", building.getBuildingId());
        BuildingImgQueryWrapper.eq("img_type", "banner");
        taBuildingImgMapper.delete(BuildingImgQueryWrapper);
        insertImgBatch(buildingImgs, building.getBuildingId());

        // tag先删除再增加
        String tagStr = object.getString("tag");
        List<TaBuildingTag> buildingTags = JSONObject.parseArray(tagStr, TaBuildingTag.class);
        QueryWrapper<TaBuildingTag> BuildingTagQueryWrapper = new QueryWrapper<>();
        BuildingTagQueryWrapper.eq("building_id", building.getBuildingId());
        taBuildingTagMapper.delete(BuildingTagQueryWrapper);
        insertTagBatch(buildingTags, building.getBuildingId());
        if(null != building.getCityId()){
            TdCity city = tdCityMapper.selectById(building.getCityId());
            city.setStatus("1");
            tdCityMapper.updateById(city);
        }

        // 项目类型
        // 先删除之前关联的
        taBuildingProjectTypeMapper.deleteByBuildingId(building.getBuildingId());
        JSONArray buildingProjectTypeArray = object.getJSONArray("buildingProjectType");
        if (CollectionUtils.isNotEmpty(buildingProjectTypeArray)) {
            taBuildingProjectTypeMapper.insertBuildingProjectTypeBatch(buildingProjectTypeArray);
        }
        return ResponseBean.success("");
    }

    @Override
    public ResponseBean appointmentList(Integer pageNum, Integer pageSize, String buildingId, String username, String phone, String status) {
        return null;
    }

    @Override
    public ResponseBean buildingAdd(String parameter) {
        JSONObject object= JSONObject.parseObject(parameter);

        TaBuilding building = JSONObject.parseObject(parameter,TaBuilding.class);
        if(null!= object.getDate("openingDate")){
            building.setOpeningDate(DateUtils.date2LocalDateTime(object.getDate("openingDate")));
        }
        building.setCreateDate(LocalDateTime.now());
        building.setStatus(0);
        if (taBuildingMapper.insert(building) < 1) {
            return ResponseBean.error("添加项目楼栋失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        if(null != building.getCityId()){
            TdCity city = tdCityMapper.selectById(building.getCityId());
            city.setStatus("1");
            tdCityMapper.updateById(city);
        }

        String imgStr = object.getString("img");
        List<TaBuildingImg> buildingImgs = JSONObject.parseArray(imgStr, TaBuildingImg.class);

//        building.setOpeningDate(DateUtils.date2LocalDateTime(object.getDate("openingDate")));
//        building.setCreateDate(LocalDateTime.now());
//        building.setStatus(0);
        insertImgBatch(buildingImgs, building.getBuildingId());

        String tagStr = object.getString("tag");
        List<TaBuildingTag> buildingTags = JSONObject.parseArray(tagStr, TaBuildingTag.class);
        insertTagBatch(buildingTags, building.getBuildingId());

        // 项目类型
        // 先删除之前关联的
        JSONArray buildingProjectTypeArray = object.getJSONArray("buildingProjectType");
        if (CollectionUtils.isNotEmpty(buildingProjectTypeArray)) {
            taBuildingProjectTypeMapper.insertBuildingProjectTypeBatch(buildingProjectTypeArray);
        }

        return ResponseBean.success("");
    }

    @Override
    public ResponseBean buildingUpdateStatus(String parameter) {
        TaBuilding  building = new TaBuilding();
        JSONObject jsonobject = JSONObject.parseObject(parameter);
        Integer  status= jsonobject.getInteger("status");
        String id = jsonobject.getString("id");
        QueryWrapper<TaBuilding> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", id);
        building.setBuildingId(id);
        building.setStatus(status);
        taBuildingMapper.update(building,buildingIdQueryWrapper);
        return ResponseBean.success("");
    }

    @Override
    public ResponseBean buildingdelete(String id) {
        TaBuilding  building = new TaBuilding();
        QueryWrapper<TaBuilding> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().eq(TaBuilding::getBuildingId,id);
        TaBuilding bui= taBuildingMapper.selectOne(buildingtWrapper);

        if (bui.getStatus().equals(1)){
            return ResponseBean.error("楼盘已发布不可以删除", ResponseBean.ERROR_UNAVAILABLE);
        }
        QueryWrapper<TaBuilding> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", id);
        building.setBuildingId(String.valueOf(id));
        building.setStatus(-1);
        taBuildingMapper.update(building,buildingIdQueryWrapper);

        return ResponseBean.success("");
    }

    @Override
    public ResponseBean buildingApartmentAdd(String parameter) {
        TaBuildingApartment building = JSONObject.parseObject(parameter,TaBuildingApartment.class);
        building.setStatus(1);
        building.setCreateDate(LocalDateTime.now());
        if (taBuildingApartmentMapper.insert(building) < 1) {
            return ResponseBean.error("新增楼盘户型失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        JSONObject jsonobject = JSONObject.parseObject(parameter);
        //图片数组
        String imgStr = jsonobject.getString("img");
        //转集合
        List<TaBuildingImg> buildingImgs = JSONObject.parseArray(imgStr, TaBuildingImg.class);
        //插入户型图片
        insertApartmentImgBatch(buildingImgs, building.getBuildingId(), building.getApartmentId());

        return ResponseBean.success("");
    }

    @Override
    public ResponseBean buildingApartmentUpdate(String parameter) {
        TaBuildingApartment building = JSONObject.parseObject(parameter,TaBuildingApartment.class);
        taBuildingImgMapper.delBuildingImgByApartment(building.getApartmentId());

        //删除户户型对应图片表
        QueryWrapper<TaApartmentImg> apartmentImgQueryWrapper = new QueryWrapper<>();
        apartmentImgQueryWrapper.eq("apartment_id", building.getApartmentId());
        taApartmentImgMapper.delete(apartmentImgQueryWrapper);

        QueryWrapper<TaBuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("apartment_id", building.getApartmentId());
        taBuildingApartmentMapper.update(building,buildingApartmentQueryWrapper);

        JSONObject jsonobject = JSONObject.parseObject(parameter);
        //图片数组
        String imgStr = jsonobject.getString("img");
        //转集合
        List<TaBuildingImg> buildingImgs = JSONObject.parseArray(imgStr, TaBuildingImg.class);
        //插入户型图片删除之前的图片
        insertApartmentImgBatch(buildingImgs, building.getBuildingId(), building.getApartmentId());

        return ResponseBean.success("");
    }

    @Override
    public ResponseBean buildingApartmentSelectId(String id) {
        //查询户型详情
        QueryWrapper<TaBuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("apartment_id", id);
        //拿到当前户型信息
        TaBuildingApartment buildingApartment = taBuildingApartmentMapper.selectOne(buildingApartmentQueryWrapper);
        if ( null == buildingApartment ){
            return ResponseBean.success("", "没有发现户型图上传");
        }

        //根据户型ID查楼盘户型对应图片表
        ArrayList arrayList= new ArrayList<>();
        QueryWrapper<TaApartmentImg> ApartmentImgQueryWrapper = new QueryWrapper<>();
        ApartmentImgQueryWrapper.eq("apartment_id", buildingApartment.getApartmentId());
        List<TaApartmentImg> buildingImg= taApartmentImgMapper.selectList(ApartmentImgQueryWrapper);
        for (TaApartmentImg apartmentImg:buildingImg){
            QueryWrapper<TaBuildingImg> buildingImgQueryWrapper = new QueryWrapper<>();
            buildingImgQueryWrapper.eq("img_id",apartmentImg.getImgId());
            buildingImgQueryWrapper.eq("img_type","aparment");
            List<TaBuildingImg> buildingImgList= taBuildingImgMapper.selectList(buildingImgQueryWrapper);
            for (TaBuildingImg buImg:buildingImgList) {
                arrayList.add(buImg);
            }
        }
        buildingApartment.setBuildingImgList(arrayList);
        return ResponseBean.success(buildingApartment);
    }

    @Override
    public ResponseBean appointmentUpdate(String id, String writeoffRemark) {
        return null;
    }

    @Override
    public ResponseBean getWxBuildingList(
            Integer pageNum,
            Integer pageSize,
            String name,
            List<String> targets,
            Integer cityId,
            boolean mine,
            String[] houseTypeList,
            String[] buildingTypeList,
            List<String[]> priceList,
            List<String[]> areaList) {
        IPage<TaBuilding> page = new Page<>(pageNum, pageSize);

        if(CollectionUtils.isEmpty(targets) && mine){
            return ResponseBean.success(page);
        }

//        QueryWrapper<TaBuilding> buildingQueryWrapper = new QueryWrapper<>();
//        buildingQueryWrapper.nested(null != name && !"".equals(name.trim()), i -> i.like("name", name).or().like("building_name", name));
//        buildingQueryWrapper.eq("status", 1);
//        buildingQueryWrapper.eq(null != cityId && cityId != 0,"city_id", cityId);
//        buildingQueryWrapper.in(null != targets && targets.size() > 0, "building_id", targets);
////        buildingQueryWrapper.like(null != name && !"".equals(name.trim()), "name", name);
//        buildingQueryWrapper.orderByAsc("order_no");
//        buildingQueryWrapper.eq(null != buildingTypeId,"building_type", buildingTypeId);
//
//        IPage<TaBuilding> result = taBuildingMapper.selectPage(page, buildingQueryWrapper);

        IPage<TaBuilding> result = taBuildingMapper.selectBuildingPage(page, name, cityId, targets, houseTypeList, buildingTypeList, priceList, areaList);

        List<TaBuilding> buildingList = result.getRecords();
        if (CollectionUtils.isNotEmpty(buildingList)) {
            for (TaBuilding build:buildingList) {
                getBuildingAttaches(build);
            }
        }

        return ResponseBean.success(result);
    }

    private void getBuildingAttaches(TaBuilding build) {
        QueryWrapper<TaBuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", build.getBuildingId());
        BuildingImgQueryWrapper.eq("img_type", "banner");
        List<TaBuildingImg> buildingImg = taBuildingImgMapper.selectList(BuildingImgQueryWrapper);
        build.setBuildingImg(buildingImg);

//            QueryWrapper<Visit> BuildingVisitQueryWrapper = new QueryWrapper<>();
//            BuildingVisitQueryWrapper.eq("visit_type", "building");
//            BuildingVisitQueryWrapper.eq("visit_content", build.getBuildingId());
//            BuildingVisitQueryWrapper.orderByDesc("visit_date");
//            List<Visit> visits = visitMapper.selectList(BuildingVisitQueryWrapper);
//            build.setVisits(visits);

        QueryWrapper<TaBuildingTag> buildingTagQueryWrapper = new QueryWrapper<>();
        buildingTagQueryWrapper.eq("building_id", build.getBuildingId());
        List<TaBuildingTag> buildingTags = taBuildingTagMapper.selectList(buildingTagQueryWrapper);
        build.setBuildingTag(buildingTags);

        IPage<TaUv> page = new Page<>(1, 10);
        QueryWrapper<TaUv> taUvQueryWrapper = new QueryWrapper<>();
        taUvQueryWrapper.eq("be_uv", build.getBuildingId());
        taUvQueryWrapper.eq("tagert_type", CommConstant.FAVOR_PROJECT);
        taUvQueryWrapper.orderByDesc("create_date");
        IPage<TaUv> taUvList = taUvMapper.selectPage(page, taUvQueryWrapper);
        build.setUvList(taUvList);


        IPage<TaShare> pg = new Page<>(1, 10);
        QueryWrapper<TaShare> taShareQueryWrapper = new QueryWrapper<>();
        taShareQueryWrapper.eq("be_share", build.getBuildingId());
        taShareQueryWrapper.eq("tagert_type", CommConstant.FAVOR_PROJECT);
        taShareQueryWrapper.orderByDesc("create_date");
        IPage<TaShare> taShareList = taShareMapper.selectPage(pg, taShareQueryWrapper);
        build.setShareList(taShareList);

        build.setConsultants(taPersonMapper.selectBuildingConsultants(build.getBuildingId(), CommConstant.PERSON_REALTY_CONSULTANT, CommConstant.STATUS_NORMAL));
    }

    @Override
    public ResponseBean getWxMainBuildingList() {
        QueryWrapper<TaBuilding> buildingQueryWrapper = new QueryWrapper<>();
        buildingQueryWrapper.eq("status", 1);
        buildingQueryWrapper.eq("is_main", 1);
        buildingQueryWrapper.orderByAsc("order_no");
        List<TaBuilding> buildingList = taBuildingMapper.selectList(buildingQueryWrapper);

        for (TaBuilding build:buildingList) {
            getBuildingAttaches(build);
        }

        return ResponseBean.success(buildingList);
    }

    @Override
    public ResponseBean getWxBuildingById(String buildingId) {
        // 楼盘信息
        QueryWrapper<TaBuilding> buildingQueryWrapper = new QueryWrapper<>();
        buildingQueryWrapper.eq("building_id", buildingId);
        TaBuilding building = taBuildingMapper.selectOne(buildingQueryWrapper);
        if (null == building) {
            return ResponseBean.error("项目不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 楼盘Banner
        QueryWrapper<TaBuildingImg> buildingImgBannerQueryWrapper = new QueryWrapper<>();
        buildingImgBannerQueryWrapper.eq("building_id", building.getBuildingId());
        buildingImgBannerQueryWrapper.eq("img_type", "banner");
        buildingImgBannerQueryWrapper.orderBy(true, true, "order_no");
        List<TaBuildingImg> buildingBannerImg = taBuildingImgMapper.selectList(buildingImgBannerQueryWrapper);

        building.setBuildingImg(buildingBannerImg);

        // 楼盘户型
        QueryWrapper<TaBuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("building_id", building.getBuildingId());
        List<TaBuildingApartment> buildingApartmentList = taBuildingApartmentMapper.selectList(buildingApartmentQueryWrapper);

        // 楼盘户型图
        buildingApartmentList.forEach(e -> {
            QueryWrapper<TaBuildingImg> buildingImgQueryWrapper = new QueryWrapper<>();
            buildingImgQueryWrapper.eq("building_id", building.getBuildingId());
            List<TaBuildingImg> buildingImgList = taBuildingImgMapper.selectList(buildingImgQueryWrapper);
            e.setBuildingImgList(buildingImgList);
        });

        Map<String, Object> buildingMap = new HashMap<>();
        buildingMap.put("info", building);
        buildingMap.put("buildingApartment", buildingApartmentList);

        return ResponseBean.success(buildingMap);
    }

    @Override
    public ResponseBean buildingApartmentBuildingId(String id) {
        QueryWrapper<TaBuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("building_id", id);
        buildingApartmentQueryWrapper.eq("status",1);
        List<TaBuildingApartment> buildingApartment= taBuildingApartmentMapper.selectList(buildingApartmentQueryWrapper);
        return ResponseBean.success(buildingApartment);
    }

    @Override
    public ResponseBean apartmentDel(String id) {
        QueryWrapper<TaBuildingApartment> buildingApartmentQueryWrapper = new QueryWrapper<>();
        buildingApartmentQueryWrapper.eq("apartment_id", id);
        TaBuildingApartment buildingApartment = taBuildingApartmentMapper.selectOne(buildingApartmentQueryWrapper);

        TaBuilding  building= new TaBuilding();
        QueryWrapper<TaBuilding> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().eq(TaBuilding::getBuildingId,buildingApartment.getBuildingId());
        TaBuilding bui= taBuildingMapper.selectOne(buildingtWrapper);

        if (bui.getStatus().equals(1)){
            return ResponseBean.error("楼盘已发布不可以删除", ResponseBean.ERROR_UNAVAILABLE);
        }

        buildingApartment.setStatus(-1);
       taBuildingApartmentMapper.update(buildingApartment,buildingApartmentQueryWrapper);

       return ResponseBean.success("");
    }

    @Override
    public ResponseBean buildingAll() {
        List<TaBuilding> taBuilding= taBuildingMapper.buildingAll();
        return ResponseBean.success(taBuilding);
    }

    @Override
    public Integer getCityById(String buildingId) {
        if (StringUtils.isEmpty(buildingId)) return null;

        TaBuilding taBuilding = taBuildingMapper.selectById(buildingId);
        if (null == taBuilding) return null;

        return taBuilding.getCityId();
    }


    int insertImgBatch(List<TaBuildingImg> imgs, String buildingId) {
        int rows = 0;
        for (TaBuildingImg img: imgs){
            TaBuildingImg Images = new TaBuildingImg();
            Images.setBuildingId(buildingId);
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(1);
            Images.setCreateDate(LocalDateTime.now());
            rows += taBuildingImgMapper.insert(Images);
        }

        return rows;
    }

    int insertTagBatch(List<TaBuildingTag> tags, String buildingId) {
        int rows = 0;
        for (TaBuildingTag tag:tags){
            TaBuildingTag btag = new TaBuildingTag();
            btag.setBuildingId(buildingId);
            btag.setTagName(tag.getTagName());
            rows += taBuildingTagMapper.insert(btag);
        }
        return rows;
    }

    int insertApartmentImgBatch(List<TaBuildingImg> imgs, String buildingId, String apartmentId) {
        int rows = 0;
        for (TaBuildingImg img: imgs){
            TaBuildingImg Images = new TaBuildingImg();
            Images.setBuildingId(buildingId);
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(1);
            Images.setCreateDate(LocalDateTime.now());

            if (taBuildingImgMapper.insert(Images) < 1) {
                continue;
            };

            TaApartmentImg apartmentImg= new TaApartmentImg();
            apartmentImg.setApartmentId(apartmentId);
            apartmentImg.setImgId(Images.getImgId());
            apartmentImg.setStatus(1);
            rows += taApartmentImgMapper.insert(apartmentImg);
        }

        return rows;
    }
}
