package com.huiju.estateagents.service.impl;

import ch.qos.logback.core.status.StatusUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaRecommendCustomer;
import com.huiju.estateagents.mapper.TaPersonMapper;
import com.huiju.estateagents.mapper.TaPersonVisitRecordMapper;
import com.huiju.estateagents.mapper.TaRecommendCustomerMapper;
import com.huiju.estateagents.service.IMiniAppService;
import com.huiju.estateagents.service.ITaRecommendCustomerService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.naming.spi.ResolveResult;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 推荐客户表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@Service
public class TaRecommendCustomerServiceImpl extends ServiceImpl<TaRecommendCustomerMapper, TaRecommendCustomer> implements ITaRecommendCustomerService {

    @Autowired
    TaPersonMapper taPersonMapper;

    @Autowired
    TaRecommendCustomerMapper taRecommendCustomerMapper;

    @Autowired
    IMiniAppService iMiniAppService;

    @Autowired
    TaPersonVisitRecordMapper taPersonVisitRecordMapper;

    @Override
    public ResponseBean getMyCustList(String openid, String keywords, int pageNumber, int pageSize) {
        List<TaPerson> taPersons = getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证当前人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        TaPerson taPerson = taPersons.get(0);

        IPage<TaRecommendCustomer> page = new Page<>();
        page.setCurrent(pageNumber);
        page.setSize(pageSize);

        QueryWrapper<TaRecommendCustomer> query = new QueryWrapper<>();
        query.eq("recommend_person", taPerson.getPersonId());
        query.like(null != keywords && "".equals(keywords.trim()), "name", keywords);
        query.orderByDesc("report_date");

        IPage<TaRecommendCustomer> result = taRecommendCustomerMapper.selectPage(page, query);
        return ResponseBean.success(result);
    }

    @Override
    public ResponseBean getCustDetail(String id) {
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(id);

        if (!StringUtils.isEmpty(taRecommendCustomer.getRealtyConsultant())) {
            TaPerson taPerson = taPersonMapper.selectById(taRecommendCustomer.getRealtyConsultant());
            if (null != taPerson) {
                taRecommendCustomer.setConsultants(new HashMap<String, Object>() {{
                    put("name", taPerson.getName());
                    put("phone", taPerson.getTel());
                    put("photo", taPerson.getPhoto());
                }});
            }
        }

        return ResponseBean.success(taRecommendCustomer);
    }

    @Override
    public ResponseBean updateCustByJSON(String paramStr) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("解析参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String checkResult = checkCustomerParams(params);
        if (null != checkResult) {
            return ResponseBean.error(checkResult, ResponseBean.ERROR_MISSING_PARAMS);
        }


        UpdateWrapper<TaRecommendCustomer> wrapper = new UpdateWrapper<>();
        wrapper.eq("customer_id", params.get("id"));
        wrapper.set("name", params.get("name"));
        wrapper.set("picture", params.get("picture"));
        wrapper.set("phone", params.get("phone"));
        wrapper.set("sex", params.get("sex"));
        wrapper.set("describe", params.get("describe"));

        String at = params.getString("appointmentTime");
        if (!StringUtils.isEmpty(at)) {
            wrapper.set("appointmentTime", DateUtils.day2LocalDateime(at));
        }
        wrapper.set("vistors", params.get("vistors"));
        wrapper.set("explain", params.get("explain"));
        wrapper.set("intention", params.get("intention"));
        wrapper.set("realtyManageType", params.get("realtyManageType"));
        wrapper.set("demandType", params.get("demandType"));
        wrapper.set("priceRange", params.get("priceRange"));
        wrapper.set("realtyConsultant", params.get("realtyConsultant"));

        // todo 需要约定时间格式
//        wrapper.set("reportDate", params.get("reportDate"));

        String status = params.getString("status");
        if (null != status) {
            wrapper.set("status", params.get("status"));
        }

        int row = taRecommendCustomerMapper.update(new TaRecommendCustomer(), wrapper);
        if (row <= 0) {
            return ResponseBean.error("更新客户信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        return ResponseBean.success("更新客户信息成功");
    }

    @Override
    public ResponseBean recommendCust(String paramStr, String openid) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("解析参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        List<TaPerson> taPersons = getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证当前人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson taPerson = taPersons.get(0);

        String checkResult = checkCustomerParams(params);
        if (null != checkResult) {
            return ResponseBean.error(checkResult, ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaRecommendCustomer taRecommendCustomer = new TaRecommendCustomer();

        taRecommendCustomer.setName(params.getString("name"));
        taRecommendCustomer.setPicture(params.getString("picture"));
        taRecommendCustomer.setPhone(params.getString("phone"));
        taRecommendCustomer.setSex(params.getInteger("sex"));
        taRecommendCustomer.setDescribe(params.getString("describe"));
        taRecommendCustomer.setRecommendPerson(params.getString("recommendPerson"));
        taRecommendCustomer.setBuildingId(params.getString("buildingId"));
        taRecommendCustomer.setReportRecommendStatus(CommConstant.RECOMMENDED);
        taRecommendCustomer.setCreateDate(LocalDateTime.now());
        taRecommendCustomer.setReportDate(LocalDateTime.now());

        // 时间格式 yyyy-MM-dd
        String at = params.getString("appointmentTime");
        if (!StringUtils.isEmpty(at)) {
            taRecommendCustomer.setAppointmentTime(DateUtils.day2LocalDateime(at));
        }

//        taRecommendCustomer.setAppointmentTime((String) params.get("appointmentTime"));
        taRecommendCustomer.setVisiteNum(params.getInteger("visiteNum"));
        taRecommendCustomer.setIntention(params.getString("intention"));
        taRecommendCustomer.setRealtyManageType(params.getString("realtyManageType"));
        taRecommendCustomer.setDemandType(params.getString("demandType"));
        taRecommendCustomer.setPriceRange(params.getString("priceRange"));
        taRecommendCustomer.setEntryType(CommConstant.ENTRY_INPUT);
        taRecommendCustomer.setVerifyStatus(CommConstant.VERIFY_READY);


        String status = params.getString("status");
        if (null == status) status = "1";
        taRecommendCustomer.setStatus(status);
        taRecommendCustomer.setRecommendPerson(taPerson.getPersonId());

        // 报备有 10 天有效期
        QueryWrapper<TaRecommendCustomer> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("name", taRecommendCustomer.getName());
        queryWrapper.eq("phone", taRecommendCustomer.getPhone());
        queryWrapper.eq("building_id",taRecommendCustomer.getBuildingId());
        List<TaRecommendCustomer> result = taRecommendCustomerMapper.selectList(queryWrapper);
        if (null != result && result.size() > 0) {
            return ResponseBean.error("当前客户已被推荐, 不能再次推荐", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        int row = taRecommendCustomerMapper.insert(taRecommendCustomer);
        if (row < 1) {
            return ResponseBean.error("推荐客户失败", ResponseBean.ERROR_UNAVAILABLE);
        }

//        // 找到销售经理，并推送消息
//        TaPerson saleMan = taPersonMapper.getSalesExecutive();
//        if (null != saleMan && !StringUtils.isEmpty(saleMan.getMiniOpenid())) {
//            // 发送消息
//            iMiniAppService.sendNewCustomerMessage(saleMan.getMiniOpenid(), CommConstant.MINIAPP_INDEX, taRecommendCustomer.getName(), taRecommendCustomer.getPhone(), "", taPerson.getName());
//        }

        return ResponseBean.success(taRecommendCustomer);
    }



    @Override
    public ResponseBean reportCust(String paramStr, String openid) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("解析参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        List<TaPerson> taPersons = getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证当前人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson taPerson = taPersons.get(0);

//        String checkResult = checkCustomerParams(params);
//        if (null != checkResult) {
//            return ResponseBean.error(checkResult, ResponseBean.ERROR_MISSING_PARAMS);
//        }

        TaRecommendCustomer taRecommendCustomer = new TaRecommendCustomer();

        taRecommendCustomer.setName(taPerson.getNickname());
        taRecommendCustomer.setPicture(taPerson.getAvatarurl());
        taRecommendCustomer.setPhone(params.getString("phone"));
        taRecommendCustomer.setSex(null == taPerson.getGender() ? null : ("1".equals(taPerson.getGender()) ? 1 : 2));
//        taRecommendCustomer.setDescribe(params.getString("describe"));
        taRecommendCustomer.setRealtyConsultant(params.getString("realtyConsultant"));
        taRecommendCustomer.setBuildingId(params.getString("buildingId"));
        taRecommendCustomer.setReportRecommendStatus(CommConstant.REPORTED);
        taRecommendCustomer.setCreateDate(LocalDateTime.now());
        taRecommendCustomer.setReportDate(LocalDateTime.now());

        // 时间格式 yyyy-MM-dd
//        String at = params.getString("appointmentTime");
//        if (!StringUtils.isEmpty(at)) {
//            taRecommendCustomer.setAppointmentTime(DateUtils.day2LocalDateime(at));
//        }ni

//        taRecommendCustomer.setAppointmentTime((String) params.get("appointmentTime"));
//        taRecommendCustomer.setVisiteNum(params.getInteger("visiteNum"));
//        taRecommendCustomer.setIntention(params.getString("intention"));
//        taRecommendCustomer.setRealtyManageType(params.getString("realtyManageType"));
//        taRecommendCustomer.setDemandType(params.getString("demandType"));
//        taRecommendCustomer.setPriceRange(params.getString("priceRange"));
        taRecommendCustomer.setEntryType(CommConstant.ENTRY_VERIFY);
        taRecommendCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
        taRecommendCustomer.setStatus(CommConstant.STATUS_NORMAL + "");


//        String status = params.getString("status");
//        if (null == status) status = "1";
//        taRecommendCustomer.setStatus(status);
//        taRecommendCustomer.setRecommendPerson(taPerson.getPersonId());
        taRecommendCustomer.setRecommendPerson(params.getString("realtyConsultant"));

        // 报备有 10 天有效期
        QueryWrapper<TaRecommendCustomer> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("name", taRecommendCustomer.getName());
        queryWrapper.eq("phone", taRecommendCustomer.getPhone());
        queryWrapper.eq("building_id",taRecommendCustomer.getBuildingId());
        List<TaRecommendCustomer> result = taRecommendCustomerMapper.selectList(queryWrapper);
        if (null != result && result.size() > 0) {
            return ResponseBean.error("当前客户已被报备, 不能再次报备", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        int row = taRecommendCustomerMapper.insert(taRecommendCustomer);
        if (row < 1) {
            return ResponseBean.error("报备客户失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 找到销售经理，并推送消息
        TaPerson saleMan = taPersonMapper.getSalesExecutive();
        if (null != saleMan && !StringUtils.isEmpty(saleMan.getMiniOpenid())) {
            // 发送消息
            iMiniAppService.sendNewCustomerMessage(saleMan.getMiniOpenid(), CommConstant.MINIAPP_INDEX, taRecommendCustomer.getName(), taRecommendCustomer.getPhone(), "", taPerson.getName());
        }

        return ResponseBean.success(taRecommendCustomer);
    }

    String checkCustomerParams(JSONObject params) {
        if (null == params.getString("name")) {
            return "请设置客户姓名";
        }
        if (null == params.getString("phone")) {
            return "请设置客户电话";
        }
        if (null == params.getInteger("sex")) {
            return "请设置客户性别";
        }
        if (null == params.getString("intention")) {
            return "请设置意向楼盘";
        }

        return null;
    }




    List<TaPerson> getPersonsByOpenId(String openid) {
        return taPersonMapper.getPersonByOpenId(openid);
    }

    @Override
    public IPage<TaRecommendCustomer> getUnSignedCustomerList(int pageNumber, int pageSize,String building,String personId){
        QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
//        queryWrapper.eq("building_id",building);
        queryWrapper.eq("realty_consultant",personId);
        queryWrapper.gt("status", CommConstant.MESSAGE_UNREAD);
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.selectPage(page,queryWrapper);
    }

    @Override
    public IPage<TaRecommendCustomer> getCustomerList(int pageNumber, int pageSize,String building,String name,String tel,String consultName,String consultTel,String entryType,String verifyStatus,Integer sex){
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.getCustomerList(page,building,name,tel,consultName,consultTel,entryType,verifyStatus,sex);
    }

    @Override
    public IPage<TaPerson> getIndependentAgents(int pageNumber, int pageSize,String name,String tel){
        IPage<TaPerson>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.getIndependentAgents(page,name,tel);
    }

    @Override
    public IPage<TaRecommendCustomer> getRecCustomerList(int pageNumber, int pageSize,String building,String name,String tel,String consultName,String consultTel,String entryType,String verifyStatus,Integer sex){
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.getRecCustomerList(page,building,name,tel,consultName,consultTel,entryType,verifyStatus,sex);
    }


    @Override
    public IPage<TaRecommendCustomer> getRepCustomerList(int pageNumber, int pageSize,String building,String name,String tel,String consultName,String consultTel,String entryType,String verifyStatus,Integer sex){
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.getRepCustomerList(page,building,name,tel,consultName,consultTel,entryType,verifyStatus,sex);
    }

    @Override
    public TaRecommendCustomer getCustomerById(String customerId){
        return taRecommendCustomerMapper.getCustomerById(customerId);
    }


    @Override
    public TaRecommendCustomer getCustomerDetail(String customerId){
        String personId = taRecommendCustomerMapper.getCustomerById(customerId).getPersonId();
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.getCustomerDetail(customerId,personId);
        if(!StringUtils.isEmpty(personId)){
            taRecommendCustomer.setVisitRecords(taPersonVisitRecordMapper.visitRecordByPersonId(personId));
            taRecommendCustomer.setVisitTimes(taPersonVisitRecordMapper.visitRecordByPersonId(personId).size());
        }
        if(!StringUtils.isEmpty(taRecommendCustomer.getRealtyConsultant())){
            TaPerson consultant =  taPersonMapper.getById(taRecommendCustomer.getRealtyConsultant());
            consultant.setProjects(taPersonMapper.getUserProjects(consultant.getPersonId()));
            taRecommendCustomer.setConsultant(consultant);
        }
        return taRecommendCustomer;
    }

    @Override
    public IPage<TaRecommendCustomer>getCustomersIRecommended(int pageNumber, int pageSize,String customerId,String building){
        QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
        // todo
        // 此处可能不是 person_id 而是 recommend_person
        queryWrapper.eq("recommend_person",customerId);
//        queryWrapper.eq("building_id",building);
        queryWrapper.eq("status", CommConstant.VERIFY_AGREE);
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.selectPage(page,queryWrapper);
    }

    @Override
    public TaRecommendCustomer newByPerson(TaPerson person) {
        // 没有手机号, 暂时不生成客户信息
        String phone = StringUtils.ifNull(person.getTel(), person.getPhone());
        if (StringUtils.isEmpty(phone)) {
            return null;
        }

        // 已经存在的, 随机返回一条记录
        List<TaRecommendCustomer> custs = getCustomerByPhone(phone);
        if (null != custs && custs.size() > 0) {
            return custs.get(0);
        }

        TaRecommendCustomer cust = new TaRecommendCustomer();
        cust.setName(StringUtils.ifNull(person.getName(), person.getNickname()));
        cust.setSex(null == person.getSex() ? str2Int(person.getGender()) : person.getSex());
        cust.setPhone(phone);
        cust.setPicture(StringUtils.ifNull(person.getPhoto(), person.getAvatarurl()));
        cust.setCountry(person.getCountry());
        cust.setCity(person.getCity());
        cust.setProvince(person.getProvince());
        // 审核同意
        cust.setVerifyStatus(CommConstant.VERIFY_AGREE);
        // 报备状态
        cust.setStatus(CommConstant.CUSTOMER_REPORT);
        // 当前日期
        cust.setReportDate(LocalDateTime.now());

        if (taRecommendCustomerMapper.insert(cust) > 0) {
            return cust;
        } else {
            log.error("依据人员新增推荐客户失败");
            return null;
        }
    }

    private List<TaRecommendCustomer> getCustomerByPhone(String phone) {
        QueryWrapper<TaRecommendCustomer> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("phone", phone);
        queryWrapper.gt("status", CommConstant.STATUS_DELETE);
        queryWrapper.orderByDesc("report_date");

        List<TaRecommendCustomer> custs = taRecommendCustomerMapper.selectList(queryWrapper);
        return custs;
    }

    private Integer str2Int(String str) {
        if (null == str) {
            return null;
        }

        try {
            return Integer.valueOf(str);
        } catch (Exception e) {
            return 0;
        }
    }
}
